# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class RUMApplicationCreateAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "name": (str,),
            "type": (str,),
        }

    attribute_map = {
        "name": "name",
        "type": "type",
    }

    def __init__(self_, name: str, type: Union[str, UnsetType] = unset, **kwargs):
        """
        RUM application creation attributes.

        :param name: Name of the RUM application.
        :type name: str

        :param type: Type of the RUM application. Supported values are ``browser`` , ``ios`` , ``android`` , ``react-native`` , ``flutter``.
        :type type: str, optional
        """
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)

        self_.name = name



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class MetricPoint(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "timestamp": (int,),
            "value": (float,),
        }

    attribute_map = {
        "timestamp": "timestamp",
        "value": "value",
    }

    def __init__(self_, timestamp: Union[int, UnsetType] = unset, value: Union[float, UnsetType] = unset, **kwargs):
        """
        A point object is of the form ``{POSIX_timestamp, numeric_value}``.

        :param timestamp: The timestamp should be in seconds and current.
            Current is defined as not more than 10 minutes in the future or more than 1 hour in the past.
        :type timestamp: int, optional

        :param value: The numeric value format should be a 64bit float gauge-type value.
        :type value: float, optional
        """
        if timestamp is not unset:
            kwargs["timestamp"] = timestamp
        if value is not unset:
            kwargs["value"] = value
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SecurityMonitoringRuleTypeCreate(ModelSimple):
    """
    The rule type.

    :param value: Must be one of ["log_detection", "workload_security"].
    :type value: str
    """

    allowed_values = {
        "log_detection",
        "workload_security",
    }
    LOG_DETECTION: ClassVar["SecurityMonitoringRuleTypeCreate"]
    WORKLOAD_SECURITY: ClassVar["SecurityMonitoringRuleTypeCreate"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SecurityMonitoringRuleTypeCreate.LOG_DETECTION = SecurityMonitoringRuleTypeCreate("log_detection")
SecurityMonitoringRuleTypeCreate.WORKLOAD_SECURITY = SecurityMonitoringRuleTypeCreate("workload_security")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class MonitorFormulaAndFunctionEventAggregation(ModelSimple):
    """
    Aggregation methods for event platform queries.

    :param value: Must be one of ["count", "cardinality", "median", "pc75", "pc90", "pc95", "pc98", "pc99", "sum", "min", "max", "avg"].
    :type value: str
    """

    allowed_values = {
        "count",
        "cardinality",
        "median",
        "pc75",
        "pc90",
        "pc95",
        "pc98",
        "pc99",
        "sum",
        "min",
        "max",
        "avg",
    }
    COUNT: ClassVar["MonitorFormulaAndFunctionEventAggregation"]
    CARDINALITY: ClassVar["MonitorFormulaAndFunctionEventAggregation"]
    MEDIAN: ClassVar["MonitorFormulaAndFunctionEventAggregation"]
    PC75: ClassVar["MonitorFormulaAndFunctionEventAggregation"]
    PC90: ClassVar["MonitorFormulaAndFunctionEventAggregation"]
    PC95: ClassVar["MonitorFormulaAndFunctionEventAggregation"]
    PC98: ClassVar["MonitorFormulaAndFunctionEventAggregation"]
    PC99: ClassVar["MonitorFormulaAndFunctionEventAggregation"]
    SUM: ClassVar["MonitorFormulaAndFunctionEventAggregation"]
    MIN: ClassVar["MonitorFormulaAndFunctionEventAggregation"]
    MAX: ClassVar["MonitorFormulaAndFunctionEventAggregation"]
    AVG: ClassVar["MonitorFormulaAndFunctionEventAggregation"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


MonitorFormulaAndFunctionEventAggregation.COUNT = MonitorFormulaAndFunctionEventAggregation("count")
MonitorFormulaAndFunctionEventAggregation.CARDINALITY = MonitorFormulaAndFunctionEventAggregation("cardinality")
MonitorFormulaAndFunctionEventAggregation.MEDIAN = MonitorFormulaAndFunctionEventAggregation("median")
MonitorFormulaAndFunctionEventAggregation.PC75 = MonitorFormulaAndFunctionEventAggregation("pc75")
MonitorFormulaAndFunctionEventAggregation.PC90 = MonitorFormulaAndFunctionEventAggregation("pc90")
MonitorFormulaAndFunctionEventAggregation.PC95 = MonitorFormulaAndFunctionEventAggregation("pc95")
MonitorFormulaAndFunctionEventAggregation.PC98 = MonitorFormulaAndFunctionEventAggregation("pc98")
MonitorFormulaAndFunctionEventAggregation.PC99 = MonitorFormulaAndFunctionEventAggregation("pc99")
MonitorFormulaAndFunctionEventAggregation.SUM = MonitorFormulaAndFunctionEventAggregation("sum")
MonitorFormulaAndFunctionEventAggregation.MIN = MonitorFormulaAndFunctionEventAggregation("min")
MonitorFormulaAndFunctionEventAggregation.MAX = MonitorFormulaAndFunctionEventAggregation("max")
MonitorFormulaAndFunctionEventAggregation.AVG = MonitorFormulaAndFunctionEventAggregation("avg")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsGlobalVariableParserType(ModelSimple):
    """
    Type of parser for a Synthetics global variable from a synthetics test.

    :param value: Must be one of ["raw", "json_path", "regex", "x_path"].
    :type value: str
    """

    allowed_values = {
        "raw",
        "json_path",
        "regex",
        "x_path",
    }
    RAW: ClassVar["SyntheticsGlobalVariableParserType"]
    JSON_PATH: ClassVar["SyntheticsGlobalVariableParserType"]
    REGEX: ClassVar["SyntheticsGlobalVariableParserType"]
    X_PATH: ClassVar["SyntheticsGlobalVariableParserType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SyntheticsGlobalVariableParserType.RAW = SyntheticsGlobalVariableParserType("raw")
SyntheticsGlobalVariableParserType.JSON_PATH = SyntheticsGlobalVariableParserType("json_path")
SyntheticsGlobalVariableParserType.REGEX = SyntheticsGlobalVariableParserType("regex")
SyntheticsGlobalVariableParserType.X_PATH = SyntheticsGlobalVariableParserType("x_path")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class AWSNamespace(ModelSimple):
    """
    The namespace associated with the tag filter entry.

    :param value: Must be one of ["elb", "application_elb", "sqs", "rds", "custom", "network_elb", "lambda"].
    :type value: str
    """

    allowed_values = {
        "elb",
        "application_elb",
        "sqs",
        "rds",
        "custom",
        "network_elb",
        "lambda",
    }
    ELB: ClassVar["AWSNamespace"]
    APPLICATION_ELB: ClassVar["AWSNamespace"]
    SQS: ClassVar["AWSNamespace"]
    RDS: ClassVar["AWSNamespace"]
    CUSTOM: ClassVar["AWSNamespace"]
    NETWORK_ELB: ClassVar["AWSNamespace"]
    LAMBDA: ClassVar["AWSNamespace"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


AWSNamespace.ELB = AWSNamespace("elb")
AWSNamespace.APPLICATION_ELB = AWSNamespace("application_elb")
AWSNamespace.SQS = AWSNamespace("sqs")
AWSNamespace.RDS = AWSNamespace("rds")
AWSNamespace.CUSTOM = AWSNamespace("custom")
AWSNamespace.NETWORK_ELB = AWSNamespace("network_elb")
AWSNamespace.LAMBDA = AWSNamespace("lambda")



"""
Update an existing incident team returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.incident_teams_api import IncidentTeamsApi
from datadog_api_client.v2.model.incident_team_type import IncidentTeamType
from datadog_api_client.v2.model.incident_team_update_attributes import IncidentTeamUpdateAttributes
from datadog_api_client.v2.model.incident_team_update_data import IncidentTeamUpdateData
from datadog_api_client.v2.model.incident_team_update_request import IncidentTeamUpdateRequest

# there is a valid "team" in the system
TEAM_DATA_ATTRIBUTES_NAME = environ["TEAM_DATA_ATTRIBUTES_NAME"]
TEAM_DATA_ID = environ["TEAM_DATA_ID"]

body = IncidentTeamUpdateRequest(
    data=IncidentTeamUpdateData(
        type=IncidentTeamType.TEAMS,
        attributes=IncidentTeamUpdateAttributes(
            name="team name-updated",
        ),
    ),
)

configuration = Configuration()
configuration.unstable_operations["update_incident_team"] = True
with ApiClient(configuration) as api_client:
    api_instance = IncidentTeamsApi(api_client)
    response = api_instance.update_incident_team(team_id=TEAM_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.service_level_objective import ServiceLevelObjective
    from datadog_api_client.v1.model.slo_list_response_metadata import SLOListResponseMetadata


class SLOListResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.service_level_objective import ServiceLevelObjective
        from datadog_api_client.v1.model.slo_list_response_metadata import SLOListResponseMetadata

        return {
            "data": ([ServiceLevelObjective],),
            "errors": ([str],),
            "metadata": (SLOListResponseMetadata,),
        }

    attribute_map = {
        "data": "data",
        "errors": "errors",
        "metadata": "metadata",
    }

    def __init__(
        self_,
        data: Union[List[ServiceLevelObjective], UnsetType] = unset,
        errors: Union[List[str], UnsetType] = unset,
        metadata: Union[SLOListResponseMetadata, UnsetType] = unset,
        **kwargs,
    ):
        """
        A response with one or more service level objective.

        :param data: An array of service level objective objects.
        :type data: [ServiceLevelObjective], optional

        :param errors: An array of error messages. Each endpoint documents how/whether this field is
            used.
        :type errors: [str], optional

        :param metadata: The metadata object containing additional information about the list of SLOs.
        :type metadata: SLOListResponseMetadata, optional
        """
        if data is not unset:
            kwargs["data"] = data
        if errors is not unset:
            kwargs["errors"] = errors
        if metadata is not unset:
            kwargs["metadata"] = metadata
        super().__init__(kwargs)



"""
Reorder Groups returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.sensitive_data_scanner_api import SensitiveDataScannerApi
from datadog_api_client.v2.model.sensitive_data_scanner_config_request import SensitiveDataScannerConfigRequest
from datadog_api_client.v2.model.sensitive_data_scanner_configuration_relationships import (
    SensitiveDataScannerConfigurationRelationships,
)
from datadog_api_client.v2.model.sensitive_data_scanner_configuration_type import SensitiveDataScannerConfigurationType
from datadog_api_client.v2.model.sensitive_data_scanner_group_item import SensitiveDataScannerGroupItem
from datadog_api_client.v2.model.sensitive_data_scanner_group_list import SensitiveDataScannerGroupList
from datadog_api_client.v2.model.sensitive_data_scanner_group_type import SensitiveDataScannerGroupType
from datadog_api_client.v2.model.sensitive_data_scanner_meta_version_only import SensitiveDataScannerMetaVersionOnly
from datadog_api_client.v2.model.sensitive_data_scanner_reorder_config import SensitiveDataScannerReorderConfig

# there is a valid "scanning_group" in the system
GROUP_DATA_ID = environ["GROUP_DATA_ID"]

# a valid "configuration" in the system
CONFIGURATION_DATA_ID = environ["CONFIGURATION_DATA_ID"]

body = SensitiveDataScannerConfigRequest(
    data=SensitiveDataScannerReorderConfig(
        relationships=SensitiveDataScannerConfigurationRelationships(
            groups=SensitiveDataScannerGroupList(
                data=[
                    SensitiveDataScannerGroupItem(
                        type=SensitiveDataScannerGroupType.SENSITIVE_DATA_SCANNER_GROUP,
                        id=GROUP_DATA_ID,
                    ),
                ],
            ),
        ),
        type=SensitiveDataScannerConfigurationType.SENSITIVE_DATA_SCANNER_CONFIGURATIONS,
        id=CONFIGURATION_DATA_ID,
    ),
    meta=SensitiveDataScannerMetaVersionOnly(),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SensitiveDataScannerApi(api_client)
    response = api_instance.reorder_scanning_groups(body=body)

    print(response)



"""
Get list of AWS log ready services returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.aws_logs_integration_api import AWSLogsIntegrationApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = AWSLogsIntegrationApi(api_client)
    response = api_instance.list_aws_logs_services()

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsPlayingTab(ModelSimple):
    """
    Navigate between different tabs for your browser test.

    :param value: Must be one of [-1, 0, 1, 2, 3].
    :type value: int
    """

    allowed_values = {
        -1,
        0,
        1,
        2,
        3,
    }
    MAIN_TAB: ClassVar["SyntheticsPlayingTab"]
    NEW_TAB: ClassVar["SyntheticsPlayingTab"]
    TAB_1: ClassVar["SyntheticsPlayingTab"]
    TAB_2: ClassVar["SyntheticsPlayingTab"]
    TAB_3: ClassVar["SyntheticsPlayingTab"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (int,),
        }


SyntheticsPlayingTab.MAIN_TAB = SyntheticsPlayingTab(-1)
SyntheticsPlayingTab.NEW_TAB = SyntheticsPlayingTab(0)
SyntheticsPlayingTab.TAB_1 = SyntheticsPlayingTab(1)
SyntheticsPlayingTab.TAB_2 = SyntheticsPlayingTab(2)
SyntheticsPlayingTab.TAB_3 = SyntheticsPlayingTab(3)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class SLOListWidgetQuery(ModelNormal):
    validations = {
        "limit": {
            "inclusive_maximum": 100,
            "inclusive_minimum": 1,
        },
    }

    @cached_property
    def openapi_types(_):
        return {
            "limit": (int,),
            "query_string": (str,),
        }

    attribute_map = {
        "limit": "limit",
        "query_string": "query_string",
    }

    def __init__(self_, query_string: str, limit: Union[int, UnsetType] = unset, **kwargs):
        """
        Updated SLO List widget.

        :param limit: Maximum number of results to display in the table.
        :type limit: int, optional

        :param query_string: Widget query.
        :type query_string: str
        """
        if limit is not unset:
            kwargs["limit"] = limit
        super().__init__(kwargs)

        self_.query_string = query_string



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
    from datadog_api_client.v1.model.geomap_widget_request import GeomapWidgetRequest
    from datadog_api_client.v1.model.geomap_widget_definition_style import GeomapWidgetDefinitionStyle
    from datadog_api_client.v1.model.widget_time import WidgetTime
    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
    from datadog_api_client.v1.model.geomap_widget_definition_type import GeomapWidgetDefinitionType
    from datadog_api_client.v1.model.geomap_widget_definition_view import GeomapWidgetDefinitionView


class GeomapWidgetDefinition(ModelNormal):
    validations = {
        "requests": {
            "max_items": 1,
            "min_items": 1,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
        from datadog_api_client.v1.model.geomap_widget_request import GeomapWidgetRequest
        from datadog_api_client.v1.model.geomap_widget_definition_style import GeomapWidgetDefinitionStyle
        from datadog_api_client.v1.model.widget_time import WidgetTime
        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
        from datadog_api_client.v1.model.geomap_widget_definition_type import GeomapWidgetDefinitionType
        from datadog_api_client.v1.model.geomap_widget_definition_view import GeomapWidgetDefinitionView

        return {
            "custom_links": ([WidgetCustomLink],),
            "requests": ([GeomapWidgetRequest],),
            "style": (GeomapWidgetDefinitionStyle,),
            "time": (WidgetTime,),
            "title": (str,),
            "title_align": (WidgetTextAlign,),
            "title_size": (str,),
            "type": (GeomapWidgetDefinitionType,),
            "view": (GeomapWidgetDefinitionView,),
        }

    attribute_map = {
        "custom_links": "custom_links",
        "requests": "requests",
        "style": "style",
        "time": "time",
        "title": "title",
        "title_align": "title_align",
        "title_size": "title_size",
        "type": "type",
        "view": "view",
    }

    def __init__(
        self_,
        requests: List[GeomapWidgetRequest],
        style: GeomapWidgetDefinitionStyle,
        type: GeomapWidgetDefinitionType,
        view: GeomapWidgetDefinitionView,
        custom_links: Union[List[WidgetCustomLink], UnsetType] = unset,
        time: Union[WidgetTime, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        title_align: Union[WidgetTextAlign, UnsetType] = unset,
        title_size: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        This visualization displays a series of values by country on a world map.

        :param custom_links: A list of custom links.
        :type custom_links: [WidgetCustomLink], optional

        :param requests: Array of one request object to display in the widget. The request must contain a ``group-by`` tag whose value is a country ISO code.

            See the `Request JSON schema documentation <https://docs.datadoghq.com/dashboards/graphing_json/request_json>`_
            for information about building the ``REQUEST_SCHEMA``.
        :type requests: [GeomapWidgetRequest]

        :param style: The style to apply to the widget.
        :type style: GeomapWidgetDefinitionStyle

        :param time: Time setting for the widget.
        :type time: WidgetTime, optional

        :param title: The title of your widget.
        :type title: str, optional

        :param title_align: How to align the text on the widget.
        :type title_align: WidgetTextAlign, optional

        :param title_size: The size of the title.
        :type title_size: str, optional

        :param type: Type of the geomap widget.
        :type type: GeomapWidgetDefinitionType

        :param view: The view of the world that the map should render.
        :type view: GeomapWidgetDefinitionView
        """
        if custom_links is not unset:
            kwargs["custom_links"] = custom_links
        if time is not unset:
            kwargs["time"] = time
        if title is not unset:
            kwargs["title"] = title
        if title_align is not unset:
            kwargs["title_align"] = title_align
        if title_size is not unset:
            kwargs["title_size"] = title_size
        super().__init__(kwargs)

        self_.requests = requests
        self_.style = style
        self_.type = type
        self_.view = view



"""
Delete a pipeline returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.logs_pipelines_api import LogsPipelinesApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = LogsPipelinesApi(api_client)
    api_instance.delete_logs_pipeline(
        pipeline_id="pipeline_id",
    )



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.security_monitoring_signal_incident_ids import SecurityMonitoringSignalIncidentIds


class SecurityMonitoringSignalIncidentsUpdateAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.security_monitoring_signal_incident_ids import (
            SecurityMonitoringSignalIncidentIds,
        )

        return {
            "incident_ids": (SecurityMonitoringSignalIncidentIds,),
            "version": (int,),
        }

    attribute_map = {
        "incident_ids": "incident_ids",
        "version": "version",
    }

    def __init__(
        self_, incident_ids: SecurityMonitoringSignalIncidentIds, version: Union[int, UnsetType] = unset, **kwargs
    ):
        """
        Attributes describing the new list of related signals for a security signal.

        :param incident_ids: Array of incidents that are associated with this signal.
        :type incident_ids: SecurityMonitoringSignalIncidentIds

        :param version: Version of the updated signal. If server side version is higher, update will be rejected.
        :type version: int, optional
        """
        if version is not unset:
            kwargs["version"] = version
        super().__init__(kwargs)

        self_.incident_ids = incident_ids



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


class SearchSLOQuery(ModelNormal):
    _nullable = True

    @cached_property
    def openapi_types(_):
        return {
            "denominator": (str,),
            "metrics": ([str], none_type),
            "numerator": (str,),
        }

    attribute_map = {
        "denominator": "denominator",
        "metrics": "metrics",
        "numerator": "numerator",
    }

    def __init__(
        self_,
        denominator: Union[str, UnsetType] = unset,
        metrics: Union[List[str], none_type, UnsetType] = unset,
        numerator: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        A metric-based SLO. **Required if type is metric**. Note that Datadog only allows the sum by aggregator
        to be used because this will sum up all request counts instead of averaging them, or taking the max or
        min of all of those requests.

        :param denominator: A Datadog metric query for total (valid) events.
        :type denominator: str, optional

        :param metrics: Metric names used in the query's numerator and denominator.
            This field will return null and will be implemented in the next version of this endpoint.
        :type metrics: [str], none_type, optional

        :param numerator: A Datadog metric query for good events.
        :type numerator: str, optional
        """
        if denominator is not unset:
            kwargs["denominator"] = denominator
        if metrics is not unset:
            kwargs["metrics"] = metrics
        if numerator is not unset:
            kwargs["numerator"] = numerator
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SecurityMonitoringRuleDetectionMethod(ModelSimple):
    """
    The detection method.

    :param value: Must be one of ["threshold", "new_value", "anomaly_detection", "impossible_travel", "hardcoded"].
    :type value: str
    """

    allowed_values = {
        "threshold",
        "new_value",
        "anomaly_detection",
        "impossible_travel",
        "hardcoded",
    }
    THRESHOLD: ClassVar["SecurityMonitoringRuleDetectionMethod"]
    NEW_VALUE: ClassVar["SecurityMonitoringRuleDetectionMethod"]
    ANOMALY_DETECTION: ClassVar["SecurityMonitoringRuleDetectionMethod"]
    IMPOSSIBLE_TRAVEL: ClassVar["SecurityMonitoringRuleDetectionMethod"]
    HARDCODED: ClassVar["SecurityMonitoringRuleDetectionMethod"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SecurityMonitoringRuleDetectionMethod.THRESHOLD = SecurityMonitoringRuleDetectionMethod("threshold")
SecurityMonitoringRuleDetectionMethod.NEW_VALUE = SecurityMonitoringRuleDetectionMethod("new_value")
SecurityMonitoringRuleDetectionMethod.ANOMALY_DETECTION = SecurityMonitoringRuleDetectionMethod("anomaly_detection")
SecurityMonitoringRuleDetectionMethod.IMPOSSIBLE_TRAVEL = SecurityMonitoringRuleDetectionMethod("impossible_travel")
SecurityMonitoringRuleDetectionMethod.HARDCODED = SecurityMonitoringRuleDetectionMethod("hardcoded")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates


class MonitorStateGroup(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates

        return {
            "last_nodata_ts": (int,),
            "last_notified_ts": (int,),
            "last_resolved_ts": (int,),
            "last_triggered_ts": (int,),
            "name": (str,),
            "status": (MonitorOverallStates,),
        }

    attribute_map = {
        "last_nodata_ts": "last_nodata_ts",
        "last_notified_ts": "last_notified_ts",
        "last_resolved_ts": "last_resolved_ts",
        "last_triggered_ts": "last_triggered_ts",
        "name": "name",
        "status": "status",
    }
    read_only_vars = {
        "status",
    }

    def __init__(
        self_,
        last_nodata_ts: Union[int, UnsetType] = unset,
        last_notified_ts: Union[int, UnsetType] = unset,
        last_resolved_ts: Union[int, UnsetType] = unset,
        last_triggered_ts: Union[int, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        status: Union[MonitorOverallStates, UnsetType] = unset,
        **kwargs,
    ):
        """
        Monitor state for a single group.

        :param last_nodata_ts: Latest timestamp the monitor was in NO_DATA state.
        :type last_nodata_ts: int, optional

        :param last_notified_ts: Latest timestamp of the notification sent for this monitor group.
        :type last_notified_ts: int, optional

        :param last_resolved_ts: Latest timestamp the monitor group was resolved.
        :type last_resolved_ts: int, optional

        :param last_triggered_ts: Latest timestamp the monitor group triggered.
        :type last_triggered_ts: int, optional

        :param name: The name of the monitor.
        :type name: str, optional

        :param status: The different states your monitor can be in.
        :type status: MonitorOverallStates, optional
        """
        if last_nodata_ts is not unset:
            kwargs["last_nodata_ts"] = last_nodata_ts
        if last_notified_ts is not unset:
            kwargs["last_notified_ts"] = last_notified_ts
        if last_resolved_ts is not unset:
            kwargs["last_resolved_ts"] = last_resolved_ts
        if last_triggered_ts is not unset:
            kwargs["last_triggered_ts"] = last_triggered_ts
        if name is not unset:
            kwargs["name"] = name
        if status is not unset:
            kwargs["status"] = status
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class HostTags(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "host": (str,),
            "tags": ([str],),
        }

    attribute_map = {
        "host": "host",
        "tags": "tags",
    }

    def __init__(self_, host: Union[str, UnsetType] = unset, tags: Union[List[str], UnsetType] = unset, **kwargs):
        """
        Set of tags to associate with your host.

        :param host: Your host name.
        :type host: str, optional

        :param tags: A list of tags to apply to the host.
        :type tags: [str], optional
        """
        if host is not unset:
            kwargs["host"] = host
        if tags is not unset:
            kwargs["tags"] = tags
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Dict, List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.check_can_delete_monitor_response_data import CheckCanDeleteMonitorResponseData


class CheckCanDeleteMonitorResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.check_can_delete_monitor_response_data import CheckCanDeleteMonitorResponseData

        return {
            "data": (CheckCanDeleteMonitorResponseData,),
            "errors": ({str: ([str],)},),
        }

    attribute_map = {
        "data": "data",
        "errors": "errors",
    }

    def __init__(
        self_, data: CheckCanDeleteMonitorResponseData, errors: Union[Dict[str, List[str]], UnsetType] = unset, **kwargs
    ):
        """
        Response of monitor IDs that can or can't be safely deleted.

        :param data: Wrapper object with the list of monitor IDs.
        :type data: CheckCanDeleteMonitorResponseData

        :param errors: A mapping of Monitor ID to strings denoting where it's used.
        :type errors: {str: ([str],)}, optional
        """
        if errors is not unset:
            kwargs["errors"] = errors
        super().__init__(kwargs)

        self_.data = data



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, List, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    UnsetType,
    unset,
)
from datadog_api_client.v1.model.aws_account_delete_request import AWSAccountDeleteRequest
from datadog_api_client.v1.model.aws_account_list_response import AWSAccountListResponse
from datadog_api_client.v1.model.aws_account_create_response import AWSAccountCreateResponse
from datadog_api_client.v1.model.aws_account import AWSAccount
from datadog_api_client.v1.model.aws_tag_filter_delete_request import AWSTagFilterDeleteRequest
from datadog_api_client.v1.model.aws_tag_filter_list_response import AWSTagFilterListResponse
from datadog_api_client.v1.model.aws_tag_filter_create_request import AWSTagFilterCreateRequest


class AWSIntegrationApi:
    """
    Configure your Datadog-AWS integration directly through the Datadog API.
    For more information, see the `AWS integration page <https://docs.datadoghq.com/integrations/amazon_web_services>`_.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_aws_account_endpoint = _Endpoint(
            settings={
                "response_type": (AWSAccountCreateResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/aws",
                "operation_id": "create_aws_account",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (AWSAccount,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._create_aws_tag_filter_endpoint = _Endpoint(
            settings={
                "response_type": (dict,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/aws/filtering",
                "operation_id": "create_aws_tag_filter",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (AWSTagFilterCreateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._create_new_aws_external_id_endpoint = _Endpoint(
            settings={
                "response_type": (AWSAccountCreateResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/aws/generate_new_external_id",
                "operation_id": "create_new_aws_external_id",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (AWSAccount,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_aws_account_endpoint = _Endpoint(
            settings={
                "response_type": (dict,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/aws",
                "operation_id": "delete_aws_account",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (AWSAccountDeleteRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_aws_tag_filter_endpoint = _Endpoint(
            settings={
                "response_type": (dict,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/aws/filtering",
                "operation_id": "delete_aws_tag_filter",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (AWSTagFilterDeleteRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._list_available_aws_namespaces_endpoint = _Endpoint(
            settings={
                "response_type": ([str],),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/aws/available_namespace_rules",
                "operation_id": "list_available_aws_namespaces",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={},
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_aws_accounts_endpoint = _Endpoint(
            settings={
                "response_type": (AWSAccountListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/aws",
                "operation_id": "list_aws_accounts",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "account_id": {
                    "openapi_types": (str,),
                    "attribute": "account_id",
                    "location": "query",
                },
                "role_name": {
                    "openapi_types": (str,),
                    "attribute": "role_name",
                    "location": "query",
                },
                "access_key_id": {
                    "openapi_types": (str,),
                    "attribute": "access_key_id",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_aws_tag_filters_endpoint = _Endpoint(
            settings={
                "response_type": (AWSTagFilterListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/aws/filtering",
                "operation_id": "list_aws_tag_filters",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "account_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "account_id",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_aws_account_endpoint = _Endpoint(
            settings={
                "response_type": (dict,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/integration/aws",
                "operation_id": "update_aws_account",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "account_id": {
                    "openapi_types": (str,),
                    "attribute": "account_id",
                    "location": "query",
                },
                "role_name": {
                    "openapi_types": (str,),
                    "attribute": "role_name",
                    "location": "query",
                },
                "access_key_id": {
                    "openapi_types": (str,),
                    "attribute": "access_key_id",
                    "location": "query",
                },
                "body": {
                    "required": True,
                    "openapi_types": (AWSAccount,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_aws_account(
        self,
        body: AWSAccount,
    ) -> AWSAccountCreateResponse:
        """Create an AWS integration.

        Create a Datadog-Amazon Web Services integration.
        Using the ``POST`` method updates your integration configuration
        by adding your new configuration to the existing one in your Datadog organization.
        A unique AWS Account ID for role based authentication.

        :param body: AWS Request Object
        :type body: AWSAccount
        :rtype: AWSAccountCreateResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_aws_account_endpoint.call_with_http_info(**kwargs)

    def create_aws_tag_filter(
        self,
        body: AWSTagFilterCreateRequest,
    ) -> dict:
        """Set an AWS tag filter.

        Set an AWS tag filter.

        :param body: Set an AWS tag filter using an ``aws_account_identifier`` , ``namespace`` , and filtering string.
            Namespace options are ``application_elb`` , ``elb`` , ``lambda`` , ``network_elb`` , ``rds`` , ``sqs`` , and ``custom``.
        :type body: AWSTagFilterCreateRequest
        :rtype: dict
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_aws_tag_filter_endpoint.call_with_http_info(**kwargs)

    def create_new_aws_external_id(
        self,
        body: AWSAccount,
    ) -> AWSAccountCreateResponse:
        """Generate a new external ID.

        Generate a new AWS external ID for a given AWS account ID and role name pair.

        :param body: Your Datadog role delegation name.
            For more information about your AWS account Role name,
            see the `Datadog AWS integration configuration info <https://docs.datadoghq.com/integrations/amazon_web_services/#setup>`_.
        :type body: AWSAccount
        :rtype: AWSAccountCreateResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_new_aws_external_id_endpoint.call_with_http_info(**kwargs)

    def delete_aws_account(
        self,
        body: AWSAccountDeleteRequest,
    ) -> dict:
        """Delete an AWS integration.

        Delete a Datadog-AWS integration matching the specified ``account_id`` and ``role_name parameters``.

        :param body: AWS request object
        :type body: AWSAccountDeleteRequest
        :rtype: dict
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._delete_aws_account_endpoint.call_with_http_info(**kwargs)

    def delete_aws_tag_filter(
        self,
        body: AWSTagFilterDeleteRequest,
    ) -> dict:
        """Delete a tag filtering entry.

        Delete a tag filtering entry.

        :param body: Delete a tag filtering entry for a given AWS account and ``dd-aws`` namespace.
        :type body: AWSTagFilterDeleteRequest
        :rtype: dict
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._delete_aws_tag_filter_endpoint.call_with_http_info(**kwargs)

    def list_available_aws_namespaces(
        self,
    ) -> List[str]:
        """List namespace rules.

        List all namespace rules for a given Datadog-AWS integration. This endpoint takes no arguments.

        :rtype: [str]
        """
        kwargs: Dict[str, Any] = {}
        return self._list_available_aws_namespaces_endpoint.call_with_http_info(**kwargs)

    def list_aws_accounts(
        self,
        *,
        account_id: Union[str, UnsetType] = unset,
        role_name: Union[str, UnsetType] = unset,
        access_key_id: Union[str, UnsetType] = unset,
    ) -> AWSAccountListResponse:
        """List all AWS integrations.

        List all Datadog-AWS integrations available in your Datadog organization.

        :param account_id: Only return AWS accounts that matches this ``account_id``.
        :type account_id: str, optional
        :param role_name: Only return AWS accounts that matches this role_name.
        :type role_name: str, optional
        :param access_key_id: Only return AWS accounts that matches this ``access_key_id``.
        :type access_key_id: str, optional
        :rtype: AWSAccountListResponse
        """
        kwargs: Dict[str, Any] = {}
        if account_id is not unset:
            kwargs["account_id"] = account_id

        if role_name is not unset:
            kwargs["role_name"] = role_name

        if access_key_id is not unset:
            kwargs["access_key_id"] = access_key_id

        return self._list_aws_accounts_endpoint.call_with_http_info(**kwargs)

    def list_aws_tag_filters(
        self,
        account_id: str,
    ) -> AWSTagFilterListResponse:
        """Get all AWS tag filters.

        Get all AWS tag filters.

        :param account_id: Only return AWS filters that matches this ``account_id``.
        :type account_id: str
        :rtype: AWSTagFilterListResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["account_id"] = account_id

        return self._list_aws_tag_filters_endpoint.call_with_http_info(**kwargs)

    def update_aws_account(
        self,
        body: AWSAccount,
        *,
        account_id: Union[str, UnsetType] = unset,
        role_name: Union[str, UnsetType] = unset,
        access_key_id: Union[str, UnsetType] = unset,
    ) -> dict:
        """Update an AWS integration.

        Update a Datadog-Amazon Web Services integration.

        :param body: AWS request object
        :type body: AWSAccount
        :param account_id: Only return AWS accounts that matches this ``account_id``.
        :type account_id: str, optional
        :param role_name: Only return AWS accounts that match this ``role_name``.
            Required if ``account_id`` is specified.
        :type role_name: str, optional
        :param access_key_id: Only return AWS accounts that matches this ``access_key_id``.
            Required if none of the other two options are specified.
        :type access_key_id: str, optional
        :rtype: dict
        """
        kwargs: Dict[str, Any] = {}
        if account_id is not unset:
            kwargs["account_id"] = account_id

        if role_name is not unset:
            kwargs["role_name"] = role_name

        if access_key_id is not unset:
            kwargs["access_key_id"] = access_key_id

        kwargs["body"] = body

        return self._update_aws_account_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Dict, List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.slo_error_budget_remaining_data import SLOErrorBudgetRemainingData
    from datadog_api_client.v1.model.slo_history_response_error_with_type import SLOHistoryResponseErrorWithType


class SLOHistorySLIData(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.slo_error_budget_remaining_data import SLOErrorBudgetRemainingData
        from datadog_api_client.v1.model.slo_history_response_error_with_type import SLOHistoryResponseErrorWithType

        return {
            "error_budget_remaining": (SLOErrorBudgetRemainingData,),
            "errors": ([SLOHistoryResponseErrorWithType],),
            "group": (str,),
            "history": ([[float]],),
            "monitor_modified": (int,),
            "monitor_type": (str,),
            "name": (str,),
            "precision": ({str: (float,)},),
            "preview": (bool,),
            "sli_value": (float,),
            "span_precision": (float,),
            "uptime": (float,),
        }

    attribute_map = {
        "error_budget_remaining": "error_budget_remaining",
        "errors": "errors",
        "group": "group",
        "history": "history",
        "monitor_modified": "monitor_modified",
        "monitor_type": "monitor_type",
        "name": "name",
        "precision": "precision",
        "preview": "preview",
        "sli_value": "sli_value",
        "span_precision": "span_precision",
        "uptime": "uptime",
    }

    def __init__(
        self_,
        error_budget_remaining: Union[SLOErrorBudgetRemainingData, UnsetType] = unset,
        errors: Union[List[SLOHistoryResponseErrorWithType], UnsetType] = unset,
        group: Union[str, UnsetType] = unset,
        history: Union[List[List[float]], UnsetType] = unset,
        monitor_modified: Union[int, UnsetType] = unset,
        monitor_type: Union[str, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        precision: Union[Dict[str, float], UnsetType] = unset,
        preview: Union[bool, UnsetType] = unset,
        sli_value: Union[float, UnsetType] = unset,
        span_precision: Union[float, UnsetType] = unset,
        uptime: Union[float, UnsetType] = unset,
        **kwargs,
    ):
        """
        An object that holds an SLI value and its associated data. It can represent an SLO's overall SLI value.
        This can also represent the SLI value for a specific monitor in multi-monitor SLOs, or a group in grouped SLOs.

        :param error_budget_remaining: A mapping of threshold ``timeframe`` to the remaining error budget.
        :type error_budget_remaining: SLOErrorBudgetRemainingData, optional

        :param errors: An array of error objects returned while querying the history data for the service level objective.
        :type errors: [SLOHistoryResponseErrorWithType], optional

        :param group: For groups in a grouped SLO, this is the group name.
        :type group: str, optional

        :param history: For ``monitor`` based SLOs, this includes the aggregated history as arrays that include time series and uptime data where ``0=monitor`` is in ``OK`` state and ``1=monitor`` is in ``alert`` state.
        :type history: [[float]], optional

        :param monitor_modified: For ``monitor`` based SLOs, this is the last modified timestamp in epoch seconds of the monitor.
        :type monitor_modified: int, optional

        :param monitor_type: For ``monitor`` based SLOs, this describes the type of monitor.
        :type monitor_type: str, optional

        :param name: For groups in a grouped SLO, this is the group name. For monitors in a multi-monitor SLO, this is the monitor name.
        :type name: str, optional

        :param precision: A mapping of threshold ``timeframe`` to number of accurate decimals, regardless of the from && to timestamp.
        :type precision: {str: (float,)}, optional

        :param preview: For ``monitor`` based SLOs, when ``true`` this indicates that a replay is in progress to give an accurate uptime
            calculation.
        :type preview: bool, optional

        :param sli_value: The current SLI value of the SLO over the history window.
        :type sli_value: float, optional

        :param span_precision: The amount of decimal places the SLI value is accurate to for the given from ``&&`` to timestamp.
        :type span_precision: float, optional

        :param uptime: Use ``sli_value`` instead. **Deprecated**.
        :type uptime: float, optional
        """
        if error_budget_remaining is not unset:
            kwargs["error_budget_remaining"] = error_budget_remaining
        if errors is not unset:
            kwargs["errors"] = errors
        if group is not unset:
            kwargs["group"] = group
        if history is not unset:
            kwargs["history"] = history
        if monitor_modified is not unset:
            kwargs["monitor_modified"] = monitor_modified
        if monitor_type is not unset:
            kwargs["monitor_type"] = monitor_type
        if name is not unset:
            kwargs["name"] = name
        if precision is not unset:
            kwargs["precision"] = precision
        if preview is not unset:
            kwargs["preview"] = preview
        if sli_value is not unset:
            kwargs["sli_value"] = sli_value
        if span_precision is not unset:
            kwargs["span_precision"] = span_precision
        if uptime is not unset:
            kwargs["uptime"] = uptime
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class LogsResponseMetadataPage(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "after": (str,),
        }

    attribute_map = {
        "after": "after",
    }

    def __init__(self_, after: Union[str, UnsetType] = unset, **kwargs):
        """
        Paging attributes.

        :param after: The cursor to use to get the next results, if any. To make the next request, use the same.
            parameters with the addition of the ``page[cursor]``.
        :type after: str, optional
        """
        if after is not unset:
            kwargs["after"] = after
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_step_type import SyntheticsStepType


class SyntheticsStep(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_step_type import SyntheticsStepType

        return {
            "allow_failure": (bool,),
            "is_critical": (bool,),
            "name": (str,),
            "no_screenshot": (bool,),
            "params": (dict,),
            "timeout": (int,),
            "type": (SyntheticsStepType,),
        }

    attribute_map = {
        "allow_failure": "allowFailure",
        "is_critical": "isCritical",
        "name": "name",
        "no_screenshot": "noScreenshot",
        "params": "params",
        "timeout": "timeout",
        "type": "type",
    }

    def __init__(
        self_,
        allow_failure: Union[bool, UnsetType] = unset,
        is_critical: Union[bool, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        no_screenshot: Union[bool, UnsetType] = unset,
        params: Union[dict, UnsetType] = unset,
        timeout: Union[int, UnsetType] = unset,
        type: Union[SyntheticsStepType, UnsetType] = unset,
        **kwargs,
    ):
        """
        The steps used in a Synthetics browser test.

        :param allow_failure: A boolean set to allow this step to fail.
        :type allow_failure: bool, optional

        :param is_critical: A boolean to use in addition to ``allowFailure`` to determine if the test should be marked as failed when the step fails.
        :type is_critical: bool, optional

        :param name: The name of the step.
        :type name: str, optional

        :param no_screenshot: A boolean set to not take a screenshot for the step.
        :type no_screenshot: bool, optional

        :param params: The parameters of the step.
        :type params: dict, optional

        :param timeout: The time before declaring a step failed.
        :type timeout: int, optional

        :param type: Step type used in your Synthetic test.
        :type type: SyntheticsStepType, optional
        """
        if allow_failure is not unset:
            kwargs["allow_failure"] = allow_failure
        if is_critical is not unset:
            kwargs["is_critical"] = is_critical
        if name is not unset:
            kwargs["name"] = name
        if no_screenshot is not unset:
            kwargs["no_screenshot"] = no_screenshot
        if params is not unset:
            kwargs["params"] = params
        if timeout is not unset:
            kwargs["timeout"] = timeout
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class HostMapWidgetDefinitionStyle(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "fill_max": (str,),
            "fill_min": (str,),
            "palette": (str,),
            "palette_flip": (bool,),
        }

    attribute_map = {
        "fill_max": "fill_max",
        "fill_min": "fill_min",
        "palette": "palette",
        "palette_flip": "palette_flip",
    }

    def __init__(
        self_,
        fill_max: Union[str, UnsetType] = unset,
        fill_min: Union[str, UnsetType] = unset,
        palette: Union[str, UnsetType] = unset,
        palette_flip: Union[bool, UnsetType] = unset,
        **kwargs,
    ):
        """
        The style to apply to the widget.

        :param fill_max: Max value to use to color the map.
        :type fill_max: str, optional

        :param fill_min: Min value to use to color the map.
        :type fill_min: str, optional

        :param palette: Color palette to apply to the widget.
        :type palette: str, optional

        :param palette_flip: Whether to flip the palette tones.
        :type palette_flip: bool, optional
        """
        if fill_max is not unset:
            kwargs["fill_max"] = fill_max
        if fill_min is not unset:
            kwargs["fill_min"] = fill_min
        if palette is not unset:
            kwargs["palette"] = palette
        if palette_flip is not unset:
            kwargs["palette_flip"] = palette_flip
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_deleted_test import SyntheticsDeletedTest


class SyntheticsDeleteTestsResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_deleted_test import SyntheticsDeletedTest

        return {
            "deleted_tests": ([SyntheticsDeletedTest],),
        }

    attribute_map = {
        "deleted_tests": "deleted_tests",
    }

    def __init__(self_, deleted_tests: Union[List[SyntheticsDeletedTest], UnsetType] = unset, **kwargs):
        """
        Response object for deleting Synthetic tests.

        :param deleted_tests: Array of objects containing a deleted Synthetic test ID with
            the associated deletion timestamp.
        :type deleted_tests: [SyntheticsDeletedTest], optional
        """
        if deleted_tests is not unset:
            kwargs["deleted_tests"] = deleted_tests
        super().__init__(kwargs)



"""
Create a user returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.users_api import UsersApi
from datadog_api_client.v2.model.user_create_attributes import UserCreateAttributes
from datadog_api_client.v2.model.user_create_data import UserCreateData
from datadog_api_client.v2.model.user_create_request import UserCreateRequest
from datadog_api_client.v2.model.users_type import UsersType

body = UserCreateRequest(
    data=UserCreateData(
        type=UsersType.USERS,
        attributes=UserCreateAttributes(
            name="Datadog API Client Python",
            email="Example-Create_a_user_returns_OK_response@datadoghq.com",
        ),
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = UsersApi(api_client)
    response = api_instance.create_user(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_test_request_certificate_item import (
        SyntheticsTestRequestCertificateItem,
    )


class SyntheticsTestRequestCertificate(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_test_request_certificate_item import (
            SyntheticsTestRequestCertificateItem,
        )

        return {
            "cert": (SyntheticsTestRequestCertificateItem,),
            "key": (SyntheticsTestRequestCertificateItem,),
        }

    attribute_map = {
        "cert": "cert",
        "key": "key",
    }

    def __init__(
        self_,
        cert: Union[SyntheticsTestRequestCertificateItem, UnsetType] = unset,
        key: Union[SyntheticsTestRequestCertificateItem, UnsetType] = unset,
        **kwargs,
    ):
        """
        Client certificate to use when performing the test request.

        :param cert: Define a request certificate.
        :type cert: SyntheticsTestRequestCertificateItem, optional

        :param key: Define a request certificate.
        :type key: SyntheticsTestRequestCertificateItem, optional
        """
        if cert is not unset:
            kwargs["cert"] = cert
        if key is not unset:
            kwargs["key"] = key
        super().__init__(kwargs)



"""
List roles returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.roles_api import RolesApi

# there is a valid "role" in the system
ROLE_DATA_ATTRIBUTES_NAME = environ["ROLE_DATA_ATTRIBUTES_NAME"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = RolesApi(api_client)
    response = api_instance.list_roles(
        filter=ROLE_DATA_ATTRIBUTES_NAME,
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.notebook_cell_response_attributes import NotebookCellResponseAttributes
    from datadog_api_client.v1.model.notebook_cell_resource_type import NotebookCellResourceType
    from datadog_api_client.v1.model.notebook_markdown_cell_attributes import NotebookMarkdownCellAttributes
    from datadog_api_client.v1.model.notebook_timeseries_cell_attributes import NotebookTimeseriesCellAttributes
    from datadog_api_client.v1.model.notebook_toplist_cell_attributes import NotebookToplistCellAttributes
    from datadog_api_client.v1.model.notebook_heat_map_cell_attributes import NotebookHeatMapCellAttributes
    from datadog_api_client.v1.model.notebook_distribution_cell_attributes import NotebookDistributionCellAttributes
    from datadog_api_client.v1.model.notebook_log_stream_cell_attributes import NotebookLogStreamCellAttributes


class NotebookCellResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.notebook_cell_response_attributes import NotebookCellResponseAttributes
        from datadog_api_client.v1.model.notebook_cell_resource_type import NotebookCellResourceType

        return {
            "attributes": (NotebookCellResponseAttributes,),
            "id": (str,),
            "type": (NotebookCellResourceType,),
        }

    attribute_map = {
        "attributes": "attributes",
        "id": "id",
        "type": "type",
    }

    def __init__(
        self_,
        attributes: Union[
            NotebookCellResponseAttributes,
            NotebookMarkdownCellAttributes,
            NotebookTimeseriesCellAttributes,
            NotebookToplistCellAttributes,
            NotebookHeatMapCellAttributes,
            NotebookDistributionCellAttributes,
            NotebookLogStreamCellAttributes,
        ],
        id: str,
        type: NotebookCellResourceType,
        **kwargs,
    ):
        """
        The description of a notebook cell response.

        :param attributes: The attributes of a notebook cell response. Valid cell types are ``markdown`` , ``timeseries`` , ``toplist`` , ``heatmap`` , ``distribution`` ,
            ``log_stream``. `More information on each graph visualization type. <https://docs.datadoghq.com/dashboards/widgets/>`_
        :type attributes: NotebookCellResponseAttributes

        :param id: Notebook cell ID.
        :type id: str

        :param type: Type of the Notebook Cell resource.
        :type type: NotebookCellResourceType
        """
        super().__init__(kwargs)

        self_.attributes = attributes
        self_.id = id
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.usage_synthetics_hour import UsageSyntheticsHour


class UsageSyntheticsResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.usage_synthetics_hour import UsageSyntheticsHour

        return {
            "usage": ([UsageSyntheticsHour],),
        }

    attribute_map = {
        "usage": "usage",
    }

    def __init__(self_, usage: Union[List[UsageSyntheticsHour], UnsetType] = unset, **kwargs):
        """
        Response containing the number of Synthetics API tests run for each hour for a given organization.

        :param usage: Array with the number of hourly Synthetics test run for a given organization.
        :type usage: [UsageSyntheticsHour], optional
        """
        if usage is not unset:
            kwargs["usage"] = usage
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsBrowserTestFailureCode(ModelSimple):
    """
    Error code that can be returned by a Synthetic test.

    :param value: Must be one of ["API_REQUEST_FAILURE", "ASSERTION_FAILURE", "DOWNLOAD_FILE_TOO_LARGE", "ELEMENT_NOT_INTERACTABLE", "EMAIL_VARIABLE_NOT_DEFINED", "EVALUATE_JAVASCRIPT", "EVALUATE_JAVASCRIPT_CONTEXT", "EXTRACT_VARIABLE", "FORBIDDEN_URL", "FRAME_DETACHED", "INCONSISTENCIES", "INTERNAL_ERROR", "INVALID_TYPE_TEXT_DELAY", "INVALID_URL", "INVALID_VARIABLE_PATTERN", "INVISIBLE_ELEMENT", "LOCATE_ELEMENT", "NAVIGATE_TO_LINK", "OPEN_URL", "PRESS_KEY", "SERVER_CERTIFICATE", "SELECT_OPTION", "STEP_TIMEOUT", "SUB_TEST_NOT_PASSED", "TEST_TIMEOUT", "TOO_MANY_HTTP_REQUESTS", "UNAVAILABLE_BROWSER", "UNKNOWN", "UNSUPPORTED_AUTH_SCHEMA", "UPLOAD_FILES_ELEMENT_TYPE", "UPLOAD_FILES_DIALOG", "UPLOAD_FILES_DYNAMIC_ELEMENT", "UPLOAD_FILES_NAME"].
    :type value: str
    """

    allowed_values = {
        "API_REQUEST_FAILURE",
        "ASSERTION_FAILURE",
        "DOWNLOAD_FILE_TOO_LARGE",
        "ELEMENT_NOT_INTERACTABLE",
        "EMAIL_VARIABLE_NOT_DEFINED",
        "EVALUATE_JAVASCRIPT",
        "EVALUATE_JAVASCRIPT_CONTEXT",
        "EXTRACT_VARIABLE",
        "FORBIDDEN_URL",
        "FRAME_DETACHED",
        "INCONSISTENCIES",
        "INTERNAL_ERROR",
        "INVALID_TYPE_TEXT_DELAY",
        "INVALID_URL",
        "INVALID_VARIABLE_PATTERN",
        "INVISIBLE_ELEMENT",
        "LOCATE_ELEMENT",
        "NAVIGATE_TO_LINK",
        "OPEN_URL",
        "PRESS_KEY",
        "SERVER_CERTIFICATE",
        "SELECT_OPTION",
        "STEP_TIMEOUT",
        "SUB_TEST_NOT_PASSED",
        "TEST_TIMEOUT",
        "TOO_MANY_HTTP_REQUESTS",
        "UNAVAILABLE_BROWSER",
        "UNKNOWN",
        "UNSUPPORTED_AUTH_SCHEMA",
        "UPLOAD_FILES_ELEMENT_TYPE",
        "UPLOAD_FILES_DIALOG",
        "UPLOAD_FILES_DYNAMIC_ELEMENT",
        "UPLOAD_FILES_NAME",
    }
    API_REQUEST_FAILURE: ClassVar["SyntheticsBrowserTestFailureCode"]
    ASSERTION_FAILURE: ClassVar["SyntheticsBrowserTestFailureCode"]
    DOWNLOAD_FILE_TOO_LARGE: ClassVar["SyntheticsBrowserTestFailureCode"]
    ELEMENT_NOT_INTERACTABLE: ClassVar["SyntheticsBrowserTestFailureCode"]
    EMAIL_VARIABLE_NOT_DEFINED: ClassVar["SyntheticsBrowserTestFailureCode"]
    EVALUATE_JAVASCRIPT: ClassVar["SyntheticsBrowserTestFailureCode"]
    EVALUATE_JAVASCRIPT_CONTEXT: ClassVar["SyntheticsBrowserTestFailureCode"]
    EXTRACT_VARIABLE: ClassVar["SyntheticsBrowserTestFailureCode"]
    FORBIDDEN_URL: ClassVar["SyntheticsBrowserTestFailureCode"]
    FRAME_DETACHED: ClassVar["SyntheticsBrowserTestFailureCode"]
    INCONSISTENCIES: ClassVar["SyntheticsBrowserTestFailureCode"]
    INTERNAL_ERROR: ClassVar["SyntheticsBrowserTestFailureCode"]
    INVALID_TYPE_TEXT_DELAY: ClassVar["SyntheticsBrowserTestFailureCode"]
    INVALID_URL: ClassVar["SyntheticsBrowserTestFailureCode"]
    INVALID_VARIABLE_PATTERN: ClassVar["SyntheticsBrowserTestFailureCode"]
    INVISIBLE_ELEMENT: ClassVar["SyntheticsBrowserTestFailureCode"]
    LOCATE_ELEMENT: ClassVar["SyntheticsBrowserTestFailureCode"]
    NAVIGATE_TO_LINK: ClassVar["SyntheticsBrowserTestFailureCode"]
    OPEN_URL: ClassVar["SyntheticsBrowserTestFailureCode"]
    PRESS_KEY: ClassVar["SyntheticsBrowserTestFailureCode"]
    SERVER_CERTIFICATE: ClassVar["SyntheticsBrowserTestFailureCode"]
    SELECT_OPTION: ClassVar["SyntheticsBrowserTestFailureCode"]
    STEP_TIMEOUT: ClassVar["SyntheticsBrowserTestFailureCode"]
    SUB_TEST_NOT_PASSED: ClassVar["SyntheticsBrowserTestFailureCode"]
    TEST_TIMEOUT: ClassVar["SyntheticsBrowserTestFailureCode"]
    TOO_MANY_HTTP_REQUESTS: ClassVar["SyntheticsBrowserTestFailureCode"]
    UNAVAILABLE_BROWSER: ClassVar["SyntheticsBrowserTestFailureCode"]
    UNKNOWN: ClassVar["SyntheticsBrowserTestFailureCode"]
    UNSUPPORTED_AUTH_SCHEMA: ClassVar["SyntheticsBrowserTestFailureCode"]
    UPLOAD_FILES_ELEMENT_TYPE: ClassVar["SyntheticsBrowserTestFailureCode"]
    UPLOAD_FILES_DIALOG: ClassVar["SyntheticsBrowserTestFailureCode"]
    UPLOAD_FILES_DYNAMIC_ELEMENT: ClassVar["SyntheticsBrowserTestFailureCode"]
    UPLOAD_FILES_NAME: ClassVar["SyntheticsBrowserTestFailureCode"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SyntheticsBrowserTestFailureCode.API_REQUEST_FAILURE = SyntheticsBrowserTestFailureCode("API_REQUEST_FAILURE")
SyntheticsBrowserTestFailureCode.ASSERTION_FAILURE = SyntheticsBrowserTestFailureCode("ASSERTION_FAILURE")
SyntheticsBrowserTestFailureCode.DOWNLOAD_FILE_TOO_LARGE = SyntheticsBrowserTestFailureCode("DOWNLOAD_FILE_TOO_LARGE")
SyntheticsBrowserTestFailureCode.ELEMENT_NOT_INTERACTABLE = SyntheticsBrowserTestFailureCode("ELEMENT_NOT_INTERACTABLE")
SyntheticsBrowserTestFailureCode.EMAIL_VARIABLE_NOT_DEFINED = SyntheticsBrowserTestFailureCode(
    "EMAIL_VARIABLE_NOT_DEFINED"
)
SyntheticsBrowserTestFailureCode.EVALUATE_JAVASCRIPT = SyntheticsBrowserTestFailureCode("EVALUATE_JAVASCRIPT")
SyntheticsBrowserTestFailureCode.EVALUATE_JAVASCRIPT_CONTEXT = SyntheticsBrowserTestFailureCode(
    "EVALUATE_JAVASCRIPT_CONTEXT"
)
SyntheticsBrowserTestFailureCode.EXTRACT_VARIABLE = SyntheticsBrowserTestFailureCode("EXTRACT_VARIABLE")
SyntheticsBrowserTestFailureCode.FORBIDDEN_URL = SyntheticsBrowserTestFailureCode("FORBIDDEN_URL")
SyntheticsBrowserTestFailureCode.FRAME_DETACHED = SyntheticsBrowserTestFailureCode("FRAME_DETACHED")
SyntheticsBrowserTestFailureCode.INCONSISTENCIES = SyntheticsBrowserTestFailureCode("INCONSISTENCIES")
SyntheticsBrowserTestFailureCode.INTERNAL_ERROR = SyntheticsBrowserTestFailureCode("INTERNAL_ERROR")
SyntheticsBrowserTestFailureCode.INVALID_TYPE_TEXT_DELAY = SyntheticsBrowserTestFailureCode("INVALID_TYPE_TEXT_DELAY")
SyntheticsBrowserTestFailureCode.INVALID_URL = SyntheticsBrowserTestFailureCode("INVALID_URL")
SyntheticsBrowserTestFailureCode.INVALID_VARIABLE_PATTERN = SyntheticsBrowserTestFailureCode("INVALID_VARIABLE_PATTERN")
SyntheticsBrowserTestFailureCode.INVISIBLE_ELEMENT = SyntheticsBrowserTestFailureCode("INVISIBLE_ELEMENT")
SyntheticsBrowserTestFailureCode.LOCATE_ELEMENT = SyntheticsBrowserTestFailureCode("LOCATE_ELEMENT")
SyntheticsBrowserTestFailureCode.NAVIGATE_TO_LINK = SyntheticsBrowserTestFailureCode("NAVIGATE_TO_LINK")
SyntheticsBrowserTestFailureCode.OPEN_URL = SyntheticsBrowserTestFailureCode("OPEN_URL")
SyntheticsBrowserTestFailureCode.PRESS_KEY = SyntheticsBrowserTestFailureCode("PRESS_KEY")
SyntheticsBrowserTestFailureCode.SERVER_CERTIFICATE = SyntheticsBrowserTestFailureCode("SERVER_CERTIFICATE")
SyntheticsBrowserTestFailureCode.SELECT_OPTION = SyntheticsBrowserTestFailureCode("SELECT_OPTION")
SyntheticsBrowserTestFailureCode.STEP_TIMEOUT = SyntheticsBrowserTestFailureCode("STEP_TIMEOUT")
SyntheticsBrowserTestFailureCode.SUB_TEST_NOT_PASSED = SyntheticsBrowserTestFailureCode("SUB_TEST_NOT_PASSED")
SyntheticsBrowserTestFailureCode.TEST_TIMEOUT = SyntheticsBrowserTestFailureCode("TEST_TIMEOUT")
SyntheticsBrowserTestFailureCode.TOO_MANY_HTTP_REQUESTS = SyntheticsBrowserTestFailureCode("TOO_MANY_HTTP_REQUESTS")
SyntheticsBrowserTestFailureCode.UNAVAILABLE_BROWSER = SyntheticsBrowserTestFailureCode("UNAVAILABLE_BROWSER")
SyntheticsBrowserTestFailureCode.UNKNOWN = SyntheticsBrowserTestFailureCode("UNKNOWN")
SyntheticsBrowserTestFailureCode.UNSUPPORTED_AUTH_SCHEMA = SyntheticsBrowserTestFailureCode("UNSUPPORTED_AUTH_SCHEMA")
SyntheticsBrowserTestFailureCode.UPLOAD_FILES_ELEMENT_TYPE = SyntheticsBrowserTestFailureCode(
    "UPLOAD_FILES_ELEMENT_TYPE"
)
SyntheticsBrowserTestFailureCode.UPLOAD_FILES_DIALOG = SyntheticsBrowserTestFailureCode("UPLOAD_FILES_DIALOG")
SyntheticsBrowserTestFailureCode.UPLOAD_FILES_DYNAMIC_ELEMENT = SyntheticsBrowserTestFailureCode(
    "UPLOAD_FILES_DYNAMIC_ELEMENT"
)
SyntheticsBrowserTestFailureCode.UPLOAD_FILES_NAME = SyntheticsBrowserTestFailureCode("UPLOAD_FILES_NAME")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class CIAppTestsQueryFilter(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "_from": (str,),
            "query": (str,),
            "to": (str,),
        }

    attribute_map = {
        "_from": "from",
        "query": "query",
        "to": "to",
    }

    def __init__(
        self_,
        _from: Union[str, UnsetType] = unset,
        query: Union[str, UnsetType] = unset,
        to: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The search and filter query settings.

        :param _from: The minimum time for the requested events; supports date, math, and regular timestamps (in milliseconds).
        :type _from: str, optional

        :param query: The search query following the Log search syntax.
        :type query: str, optional

        :param to: The maximum time for the requested events, supports date, math, and regular timestamps (in milliseconds).
        :type to: str, optional
        """
        if _from is not unset:
            kwargs["_from"] = _from
        if query is not unset:
            kwargs["query"] = query
        if to is not unset:
            kwargs["to"] = to
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class IncidentFieldAttributesValueType(ModelSimple):
    """
    Type of the multiple value field definitions.

    :param value: If omitted defaults to "multiselect". Must be one of ["multiselect", "textarray", "metrictag", "autocomplete"].
    :type value: str
    """

    allowed_values = {
        "multiselect",
        "textarray",
        "metrictag",
        "autocomplete",
    }
    MULTISELECT: ClassVar["IncidentFieldAttributesValueType"]
    TEXTARRAY: ClassVar["IncidentFieldAttributesValueType"]
    METRICTAG: ClassVar["IncidentFieldAttributesValueType"]
    AUTOCOMPLETE: ClassVar["IncidentFieldAttributesValueType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


IncidentFieldAttributesValueType.MULTISELECT = IncidentFieldAttributesValueType("multiselect")
IncidentFieldAttributesValueType.TEXTARRAY = IncidentFieldAttributesValueType("textarray")
IncidentFieldAttributesValueType.METRICTAG = IncidentFieldAttributesValueType("metrictag")
IncidentFieldAttributesValueType.AUTOCOMPLETE = IncidentFieldAttributesValueType("autocomplete")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Dict, List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class AWSAccount(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "access_key_id": (str,),
            "account_id": (str,),
            "account_specific_namespace_rules": ({str: (bool,)},),
            "cspm_resource_collection_enabled": (bool,),
            "excluded_regions": ([str],),
            "filter_tags": ([str],),
            "host_tags": ([str],),
            "metrics_collection_enabled": (bool,),
            "resource_collection_enabled": (bool,),
            "role_name": (str,),
            "secret_access_key": (str,),
        }

    attribute_map = {
        "access_key_id": "access_key_id",
        "account_id": "account_id",
        "account_specific_namespace_rules": "account_specific_namespace_rules",
        "cspm_resource_collection_enabled": "cspm_resource_collection_enabled",
        "excluded_regions": "excluded_regions",
        "filter_tags": "filter_tags",
        "host_tags": "host_tags",
        "metrics_collection_enabled": "metrics_collection_enabled",
        "resource_collection_enabled": "resource_collection_enabled",
        "role_name": "role_name",
        "secret_access_key": "secret_access_key",
    }

    def __init__(
        self_,
        access_key_id: Union[str, UnsetType] = unset,
        account_id: Union[str, UnsetType] = unset,
        account_specific_namespace_rules: Union[Dict[str, bool], UnsetType] = unset,
        cspm_resource_collection_enabled: Union[bool, UnsetType] = unset,
        excluded_regions: Union[List[str], UnsetType] = unset,
        filter_tags: Union[List[str], UnsetType] = unset,
        host_tags: Union[List[str], UnsetType] = unset,
        metrics_collection_enabled: Union[bool, UnsetType] = unset,
        resource_collection_enabled: Union[bool, UnsetType] = unset,
        role_name: Union[str, UnsetType] = unset,
        secret_access_key: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Returns the AWS account associated with this integration.

        :param access_key_id: Your AWS access key ID. Only required if your AWS account is a GovCloud or China account.
        :type access_key_id: str, optional

        :param account_id: Your AWS Account ID without dashes.
        :type account_id: str, optional

        :param account_specific_namespace_rules: An object, (in the form ``{"namespace1":true/false, "namespace2":true/false}`` ),
            that enables or disables metric collection for specific AWS namespaces for this
            AWS account only.
        :type account_specific_namespace_rules: {str: (bool,)}, optional

        :param cspm_resource_collection_enabled: Whether Datadog collects cloud security posture management resources from your AWS account. This includes additional resources not covered under the general ``resource_collection``.
        :type cspm_resource_collection_enabled: bool, optional

        :param excluded_regions: An array of AWS regions to exclude from metrics collection.
        :type excluded_regions: [str], optional

        :param filter_tags: The array of EC2 tags (in the form ``key:value`` ) defines a filter that Datadog uses when collecting metrics from EC2.
            Wildcards, such as ``?`` (for single characters) and ``*`` (for multiple characters) can also be used.
            Only hosts that match one of the defined tags
            will be imported into Datadog. The rest will be ignored.
            Host matching a given tag can also be excluded by adding ``!`` before the tag.
            For example, ``env:production,instance-type:c1.*,!region:us-east-1``
        :type filter_tags: [str], optional

        :param host_tags: Array of tags (in the form ``key:value`` ) to add to all hosts
            and metrics reporting through this integration.
        :type host_tags: [str], optional

        :param metrics_collection_enabled: Whether Datadog collects metrics for this AWS account.
        :type metrics_collection_enabled: bool, optional

        :param resource_collection_enabled: Whether Datadog collects a standard set of resources from your AWS account.
        :type resource_collection_enabled: bool, optional

        :param role_name: Your Datadog role delegation name.
        :type role_name: str, optional

        :param secret_access_key: Your AWS secret access key. Only required if your AWS account is a GovCloud or China account.
        :type secret_access_key: str, optional
        """
        if access_key_id is not unset:
            kwargs["access_key_id"] = access_key_id
        if account_id is not unset:
            kwargs["account_id"] = account_id
        if account_specific_namespace_rules is not unset:
            kwargs["account_specific_namespace_rules"] = account_specific_namespace_rules
        if cspm_resource_collection_enabled is not unset:
            kwargs["cspm_resource_collection_enabled"] = cspm_resource_collection_enabled
        if excluded_regions is not unset:
            kwargs["excluded_regions"] = excluded_regions
        if filter_tags is not unset:
            kwargs["filter_tags"] = filter_tags
        if host_tags is not unset:
            kwargs["host_tags"] = host_tags
        if metrics_collection_enabled is not unset:
            kwargs["metrics_collection_enabled"] = metrics_collection_enabled
        if resource_collection_enabled is not unset:
            kwargs["resource_collection_enabled"] = resource_collection_enabled
        if role_name is not unset:
            kwargs["role_name"] = role_name
        if secret_access_key is not unset:
            kwargs["secret_access_key"] = secret_access_key
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class WidgetCompareTo(ModelSimple):
    """
    Timeframe used for the change comparison.

    :param value: Must be one of ["hour_before", "day_before", "week_before", "month_before"].
    :type value: str
    """

    allowed_values = {
        "hour_before",
        "day_before",
        "week_before",
        "month_before",
    }
    HOUR_BEFORE: ClassVar["WidgetCompareTo"]
    DAY_BEFORE: ClassVar["WidgetCompareTo"]
    WEEK_BEFORE: ClassVar["WidgetCompareTo"]
    MONTH_BEFORE: ClassVar["WidgetCompareTo"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


WidgetCompareTo.HOUR_BEFORE = WidgetCompareTo("hour_before")
WidgetCompareTo.DAY_BEFORE = WidgetCompareTo("day_before")
WidgetCompareTo.WEEK_BEFORE = WidgetCompareTo("week_before")
WidgetCompareTo.MONTH_BEFORE = WidgetCompareTo("month_before")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


class UsageFargateHour(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "apm_fargate_count": (int,),
            "appsec_fargate_count": (int,),
            "avg_profiled_fargate_tasks": (int,),
            "hour": (datetime,),
            "org_name": (str,),
            "public_id": (str,),
            "tasks_count": (int,),
        }

    attribute_map = {
        "apm_fargate_count": "apm_fargate_count",
        "appsec_fargate_count": "appsec_fargate_count",
        "avg_profiled_fargate_tasks": "avg_profiled_fargate_tasks",
        "hour": "hour",
        "org_name": "org_name",
        "public_id": "public_id",
        "tasks_count": "tasks_count",
    }

    def __init__(
        self_,
        apm_fargate_count: Union[int, UnsetType] = unset,
        appsec_fargate_count: Union[int, UnsetType] = unset,
        avg_profiled_fargate_tasks: Union[int, UnsetType] = unset,
        hour: Union[datetime, UnsetType] = unset,
        org_name: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        tasks_count: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        Number of Fargate tasks run and hourly usage.

        :param apm_fargate_count: The high-water mark of APM ECS Fargate tasks during the given hour.
        :type apm_fargate_count: int, optional

        :param appsec_fargate_count: The Application Security Monitoring ECS Fargate tasks during the given hour.
        :type appsec_fargate_count: int, optional

        :param avg_profiled_fargate_tasks: The average profiled task count for Fargate Profiling.
        :type avg_profiled_fargate_tasks: int, optional

        :param hour: The hour for the usage.
        :type hour: datetime, optional

        :param org_name: The organization name.
        :type org_name: str, optional

        :param public_id: The organization public ID.
        :type public_id: str, optional

        :param tasks_count: The number of Fargate tasks run.
        :type tasks_count: int, optional
        """
        if apm_fargate_count is not unset:
            kwargs["apm_fargate_count"] = apm_fargate_count
        if appsec_fargate_count is not unset:
            kwargs["appsec_fargate_count"] = appsec_fargate_count
        if avg_profiled_fargate_tasks is not unset:
            kwargs["avg_profiled_fargate_tasks"] = avg_profiled_fargate_tasks
        if hour is not unset:
            kwargs["hour"] = hour
        if org_name is not unset:
            kwargs["org_name"] = org_name
        if public_id is not unset:
            kwargs["public_id"] = public_id
        if tasks_count is not unset:
            kwargs["tasks_count"] = tasks_count
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.search_slo_response_data_attributes_facets_object_string import (
        SearchSLOResponseDataAttributesFacetsObjectString,
    )
    from datadog_api_client.v1.model.search_slo_response_data_attributes_facets_object_int import (
        SearchSLOResponseDataAttributesFacetsObjectInt,
    )


class SearchSLOResponseDataAttributesFacets(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.search_slo_response_data_attributes_facets_object_string import (
            SearchSLOResponseDataAttributesFacetsObjectString,
        )
        from datadog_api_client.v1.model.search_slo_response_data_attributes_facets_object_int import (
            SearchSLOResponseDataAttributesFacetsObjectInt,
        )

        return {
            "all_tags": ([SearchSLOResponseDataAttributesFacetsObjectString],),
            "creator_name": ([SearchSLOResponseDataAttributesFacetsObjectString],),
            "env_tags": ([SearchSLOResponseDataAttributesFacetsObjectString],),
            "service_tags": ([SearchSLOResponseDataAttributesFacetsObjectString],),
            "slo_type": ([SearchSLOResponseDataAttributesFacetsObjectInt],),
            "target": ([SearchSLOResponseDataAttributesFacetsObjectInt],),
            "team_tags": ([SearchSLOResponseDataAttributesFacetsObjectString],),
            "timeframe": ([SearchSLOResponseDataAttributesFacetsObjectString],),
        }

    attribute_map = {
        "all_tags": "all_tags",
        "creator_name": "creator_name",
        "env_tags": "env_tags",
        "service_tags": "service_tags",
        "slo_type": "slo_type",
        "target": "target",
        "team_tags": "team_tags",
        "timeframe": "timeframe",
    }

    def __init__(
        self_,
        all_tags: Union[List[SearchSLOResponseDataAttributesFacetsObjectString], UnsetType] = unset,
        creator_name: Union[List[SearchSLOResponseDataAttributesFacetsObjectString], UnsetType] = unset,
        env_tags: Union[List[SearchSLOResponseDataAttributesFacetsObjectString], UnsetType] = unset,
        service_tags: Union[List[SearchSLOResponseDataAttributesFacetsObjectString], UnsetType] = unset,
        slo_type: Union[List[SearchSLOResponseDataAttributesFacetsObjectInt], UnsetType] = unset,
        target: Union[List[SearchSLOResponseDataAttributesFacetsObjectInt], UnsetType] = unset,
        team_tags: Union[List[SearchSLOResponseDataAttributesFacetsObjectString], UnsetType] = unset,
        timeframe: Union[List[SearchSLOResponseDataAttributesFacetsObjectString], UnsetType] = unset,
        **kwargs,
    ):
        """
        Facets

        :param all_tags: All tags associated with an SLO.
        :type all_tags: [SearchSLOResponseDataAttributesFacetsObjectString], optional

        :param creator_name: Creator of an SLO.
        :type creator_name: [SearchSLOResponseDataAttributesFacetsObjectString], optional

        :param env_tags: Tags with the ``env`` tag key.
        :type env_tags: [SearchSLOResponseDataAttributesFacetsObjectString], optional

        :param service_tags: Tags with the ``service`` tag key.
        :type service_tags: [SearchSLOResponseDataAttributesFacetsObjectString], optional

        :param slo_type: Type of SLO.
        :type slo_type: [SearchSLOResponseDataAttributesFacetsObjectInt], optional

        :param target: SLO Target
        :type target: [SearchSLOResponseDataAttributesFacetsObjectInt], optional

        :param team_tags: Tags with the ``team`` tag key.
        :type team_tags: [SearchSLOResponseDataAttributesFacetsObjectString], optional

        :param timeframe: Timeframes of SLOs.
        :type timeframe: [SearchSLOResponseDataAttributesFacetsObjectString], optional
        """
        if all_tags is not unset:
            kwargs["all_tags"] = all_tags
        if creator_name is not unset:
            kwargs["creator_name"] = creator_name
        if env_tags is not unset:
            kwargs["env_tags"] = env_tags
        if service_tags is not unset:
            kwargs["service_tags"] = service_tags
        if slo_type is not unset:
            kwargs["slo_type"] = slo_type
        if target is not unset:
            kwargs["target"] = target
        if team_tags is not unset:
            kwargs["team_tags"] = team_tags
        if timeframe is not unset:
            kwargs["timeframe"] = timeframe
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class HostMuteSettings(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "end": (int,),
            "message": (str,),
            "override": (bool,),
        }

    attribute_map = {
        "end": "end",
        "message": "message",
        "override": "override",
    }

    def __init__(
        self_,
        end: Union[int, UnsetType] = unset,
        message: Union[str, UnsetType] = unset,
        override: Union[bool, UnsetType] = unset,
        **kwargs,
    ):
        """
        Combination of settings to mute a host.

        :param end: POSIX timestamp in seconds when the host is unmuted. If omitted, the host remains muted until explicitly unmuted.
        :type end: int, optional

        :param message: Message to associate with the muting of this host.
        :type message: str, optional

        :param override: If true and the host is already muted, replaces existing host mute settings.
        :type override: bool, optional
        """
        if end is not unset:
            kwargs["end"] = end
        if message is not unset:
            kwargs["message"] = message
        if override is not unset:
            kwargs["override"] = override
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.usage_time_series_object import UsageTimeSeriesObject
    from datadog_api_client.v2.model.hourly_usage_type import HourlyUsageType


class UsageAttributesObject(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.usage_time_series_object import UsageTimeSeriesObject
        from datadog_api_client.v2.model.hourly_usage_type import HourlyUsageType

        return {
            "org_name": (str,),
            "product_family": (str,),
            "public_id": (str,),
            "timeseries": ([UsageTimeSeriesObject],),
            "usage_type": (HourlyUsageType,),
        }

    attribute_map = {
        "org_name": "org_name",
        "product_family": "product_family",
        "public_id": "public_id",
        "timeseries": "timeseries",
        "usage_type": "usage_type",
    }

    def __init__(
        self_,
        org_name: Union[str, UnsetType] = unset,
        product_family: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        timeseries: Union[List[UsageTimeSeriesObject], UnsetType] = unset,
        usage_type: Union[HourlyUsageType, UnsetType] = unset,
        **kwargs,
    ):
        """
        Usage attributes data.

        :param org_name: The organization name.
        :type org_name: str, optional

        :param product_family: The product for which usage is being reported.
        :type product_family: str, optional

        :param public_id: The organization public ID.
        :type public_id: str, optional

        :param timeseries: List of usage data reported for each requested hour.
        :type timeseries: [UsageTimeSeriesObject], optional

        :param usage_type: Usage type that is being measured.
        :type usage_type: HourlyUsageType, optional
        """
        if org_name is not unset:
            kwargs["org_name"] = org_name
        if product_family is not unset:
            kwargs["product_family"] = product_family
        if public_id is not unset:
            kwargs["public_id"] = public_id
        if timeseries is not unset:
            kwargs["timeseries"] = timeseries
        if usage_type is not unset:
            kwargs["usage_type"] = usage_type
        super().__init__(kwargs)



"""
Update a tag configuration returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.metrics_api import MetricsApi
from datadog_api_client.v2.model.metric_tag_configuration_type import MetricTagConfigurationType
from datadog_api_client.v2.model.metric_tag_configuration_update_attributes import (
    MetricTagConfigurationUpdateAttributes,
)
from datadog_api_client.v2.model.metric_tag_configuration_update_data import MetricTagConfigurationUpdateData
from datadog_api_client.v2.model.metric_tag_configuration_update_request import MetricTagConfigurationUpdateRequest

# there is a valid "metric_tag_configuration" in the system
METRIC_TAG_CONFIGURATION_DATA_ID = environ["METRIC_TAG_CONFIGURATION_DATA_ID"]

body = MetricTagConfigurationUpdateRequest(
    data=MetricTagConfigurationUpdateData(
        type=MetricTagConfigurationType.MANAGE_TAGS,
        id=METRIC_TAG_CONFIGURATION_DATA_ID,
        attributes=MetricTagConfigurationUpdateAttributes(
            tags=[
                "app",
            ],
        ),
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = MetricsApi(api_client)
    response = api_instance.update_tag_configuration(metric_name=METRIC_TAG_CONFIGURATION_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, Union
import warnings

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    UnsetType,
    unset,
)
from datadog_api_client.v1.model.logs_list_response import LogsListResponse
from datadog_api_client.v1.model.logs_list_request import LogsListRequest
from datadog_api_client.v1.model.content_encoding import ContentEncoding
from datadog_api_client.v1.model.http_log import HTTPLog


class LogsApi:
    """
    Search your logs and send them to your Datadog platform over HTTP.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._list_logs_endpoint = _Endpoint(
            settings={
                "response_type": (LogsListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/logs-queries/list",
                "operation_id": "list_logs",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (LogsListRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._submit_log_endpoint = _Endpoint(
            settings={
                "response_type": (dict,),
                "auth": ["apiKeyAuth"],
                "endpoint_path": "/v1/input",
                "operation_id": "submit_log",
                "http_method": "POST",
                "version": "v1",
                "servers": [
                    {
                        "url": "https://{subdomain}.{site}",
                        "variables": {
                            "site": {
                                "description": "The regional site for Datadog customers.",
                                "default_value": "datadoghq.com",
                                "enum_values": [
                                    "datadoghq.com",
                                    "us3.datadoghq.com",
                                    "us5.datadoghq.com",
                                    "datadoghq.eu",
                                    "ddog-gov.com",
                                ],
                            },
                            "subdomain": {
                                "description": "The subdomain where the API is deployed.",
                                "default_value": "http-intake.logs",
                            },
                        },
                    },
                    {
                        "url": "{protocol}://{name}",
                        "variables": {
                            "name": {
                                "description": "Full site DNS name.",
                                "default_value": "http-intake.logs.datadoghq.com",
                            },
                            "protocol": {
                                "description": "The protocol for accessing the API.",
                                "default_value": "https",
                            },
                        },
                    },
                    {
                        "url": "https://{subdomain}.{site}",
                        "variables": {
                            "site": {
                                "description": "Any Datadog deployment.",
                                "default_value": "datadoghq.com",
                            },
                            "subdomain": {
                                "description": "The subdomain where the API is deployed.",
                                "default_value": "http-intake.logs",
                            },
                        },
                    },
                ],
            },
            params_map={
                "content_encoding": {
                    "openapi_types": (ContentEncoding,),
                    "attribute": "Content-Encoding",
                    "location": "header",
                },
                "ddtags": {
                    "openapi_types": (str,),
                    "attribute": "ddtags",
                    "location": "query",
                },
                "body": {
                    "required": True,
                    "openapi_types": (HTTPLog,),
                    "location": "body",
                    "collection_format": "multi",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": ["application/json", "application/json;simple", "application/logplex-1", "text/plain"],
            },
            api_client=api_client,
        )

    def list_logs(
        self,
        body: LogsListRequest,
    ) -> LogsListResponse:
        """Search logs.

        List endpoint returns logs that match a log search query.
        `Results are paginated </logs/guide/collect-multiple-logs-with-pagination>`_.

        If you are considering archiving logs for your organization,
        consider use of the Datadog archive capabilities instead of the log list API.
        See `Datadog Logs Archive documentation <https://docs.datadoghq.com/logs/archives>`_.

        :param body: Logs filter
        :type body: LogsListRequest
        :rtype: LogsListResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._list_logs_endpoint.call_with_http_info(**kwargs)

    def submit_log(
        self,
        body: HTTPLog,
        *,
        content_encoding: Union[ContentEncoding, UnsetType] = unset,
        ddtags: Union[str, UnsetType] = unset,
    ) -> dict:
        """Send logs. **Deprecated**.

        Send your logs to your Datadog platform over HTTP. Limits per HTTP request are:

        * Maximum content size per payload (uncompressed): 5MB
        * Maximum size for a single log: 1MB
        * Maximum array size if sending multiple logs in an array: 1000 entries

        Any log exceeding 1MB is accepted and truncated by Datadog:

        * For a single log request, the API truncates the log at 1MB and returns a 2xx.
        * For a multi-logs request, the API processes all logs, truncates only logs larger than 1MB, and returns a 2xx.

        Datadog recommends sending your logs compressed.
        Add the ``Content-Encoding: gzip`` header to the request when sending compressed logs.

        The status codes answered by the HTTP API are:

        * 200: OK
        * 400: Bad request (likely an issue in the payload formatting)
        * 403: Permission issue (likely using an invalid API Key)
        * 413: Payload too large (batch is above 5MB uncompressed)
        * 5xx: Internal error, request should be retried after some time

        :param body: Log to send (JSON format).
        :type body: HTTPLog
        :param content_encoding: HTTP header used to compress the media-type.
        :type content_encoding: ContentEncoding, optional
        :param ddtags: Log tags can be passed as query parameters with ``text/plain`` content type.
        :type ddtags: str, optional
        :rtype: dict
        """
        kwargs: Dict[str, Any] = {}
        if content_encoding is not unset:
            kwargs["content_encoding"] = content_encoding

        if ddtags is not unset:
            kwargs["ddtags"] = ddtags

        kwargs["body"] = body

        warnings.warn("submit_log is deprecated", DeprecationWarning, stacklevel=2)
        return self._submit_log_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_test_pause_status import SyntheticsTestPauseStatus


class SyntheticsUpdateTestPauseStatusPayload(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_test_pause_status import SyntheticsTestPauseStatus

        return {
            "new_status": (SyntheticsTestPauseStatus,),
        }

    attribute_map = {
        "new_status": "new_status",
    }

    def __init__(self_, new_status: Union[SyntheticsTestPauseStatus, UnsetType] = unset, **kwargs):
        """
        Object to start or pause an existing Synthetic test.

        :param new_status: Define whether you want to start ( ``live`` ) or pause ( ``paused`` ) a
            Synthetic test.
        :type new_status: SyntheticsTestPauseStatus, optional
        """
        if new_status is not unset:
            kwargs["new_status"] = new_status
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    UnsetType,
    unset,
)
from datadog_api_client.v2.model.user_response import UserResponse
from datadog_api_client.v2.model.service_account_create_request import ServiceAccountCreateRequest
from datadog_api_client.v2.model.user_invitations_response import UserInvitationsResponse
from datadog_api_client.v2.model.user_invitations_request import UserInvitationsRequest
from datadog_api_client.v2.model.user_invitation_response import UserInvitationResponse
from datadog_api_client.v2.model.users_response import UsersResponse
from datadog_api_client.v2.model.query_sort_order import QuerySortOrder
from datadog_api_client.v2.model.user_create_request import UserCreateRequest
from datadog_api_client.v2.model.user_update_request import UserUpdateRequest
from datadog_api_client.v2.model.permissions_response import PermissionsResponse


class UsersApi:
    """
    Create, edit, and disable users.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_service_account_endpoint = _Endpoint(
            settings={
                "response_type": (UserResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/service_accounts",
                "operation_id": "create_service_account",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (ServiceAccountCreateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._create_user_endpoint = _Endpoint(
            settings={
                "response_type": (UserResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/users",
                "operation_id": "create_user",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (UserCreateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._disable_user_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/users/{user_id}",
                "operation_id": "disable_user",
                "http_method": "DELETE",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "user_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "user_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_invitation_endpoint = _Endpoint(
            settings={
                "response_type": (UserInvitationResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/user_invitations/{user_invitation_uuid}",
                "operation_id": "get_invitation",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "user_invitation_uuid": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "user_invitation_uuid",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_user_endpoint = _Endpoint(
            settings={
                "response_type": (UserResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/users/{user_id}",
                "operation_id": "get_user",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "user_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "user_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_user_organizations_endpoint = _Endpoint(
            settings={
                "response_type": (UserResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/users/{user_id}/orgs",
                "operation_id": "list_user_organizations",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "user_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "user_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_user_permissions_endpoint = _Endpoint(
            settings={
                "response_type": (PermissionsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/users/{user_id}/permissions",
                "operation_id": "list_user_permissions",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "user_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "user_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_users_endpoint = _Endpoint(
            settings={
                "response_type": (UsersResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/users",
                "operation_id": "list_users",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "page_size": {
                    "openapi_types": (int,),
                    "attribute": "page[size]",
                    "location": "query",
                },
                "page_number": {
                    "openapi_types": (int,),
                    "attribute": "page[number]",
                    "location": "query",
                },
                "sort": {
                    "openapi_types": (str,),
                    "attribute": "sort",
                    "location": "query",
                },
                "sort_dir": {
                    "openapi_types": (QuerySortOrder,),
                    "attribute": "sort_dir",
                    "location": "query",
                },
                "filter": {
                    "openapi_types": (str,),
                    "attribute": "filter",
                    "location": "query",
                },
                "filter_status": {
                    "openapi_types": (str,),
                    "attribute": "filter[status]",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._send_invitations_endpoint = _Endpoint(
            settings={
                "response_type": (UserInvitationsResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/user_invitations",
                "operation_id": "send_invitations",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (UserInvitationsRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._update_user_endpoint = _Endpoint(
            settings={
                "response_type": (UserResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v2/users/{user_id}",
                "operation_id": "update_user",
                "http_method": "PATCH",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "user_id": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "user_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (UserUpdateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_service_account(
        self,
        body: ServiceAccountCreateRequest,
    ) -> UserResponse:
        """Create a service account.

        Create a service account for your organization.

        :type body: ServiceAccountCreateRequest
        :rtype: UserResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_service_account_endpoint.call_with_http_info(**kwargs)

    def create_user(
        self,
        body: UserCreateRequest,
    ) -> UserResponse:
        """Create a user.

        Create a user for your organization.

        :type body: UserCreateRequest
        :rtype: UserResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_user_endpoint.call_with_http_info(**kwargs)

    def disable_user(
        self,
        user_id: str,
    ) -> None:
        """Disable a user.

        Disable a user. Can only be used with an application key belonging
        to an administrator user.

        :param user_id: The ID of the user.
        :type user_id: str
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["user_id"] = user_id

        return self._disable_user_endpoint.call_with_http_info(**kwargs)

    def get_invitation(
        self,
        user_invitation_uuid: str,
    ) -> UserInvitationResponse:
        """Get a user invitation.

        Returns a single user invitation by its UUID.

        :param user_invitation_uuid: The UUID of the user invitation.
        :type user_invitation_uuid: str
        :rtype: UserInvitationResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["user_invitation_uuid"] = user_invitation_uuid

        return self._get_invitation_endpoint.call_with_http_info(**kwargs)

    def get_user(
        self,
        user_id: str,
    ) -> UserResponse:
        """Get user details.

        Get a user in the organization specified by the user’s ``user_id``.

        :param user_id: The ID of the user.
        :type user_id: str
        :rtype: UserResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["user_id"] = user_id

        return self._get_user_endpoint.call_with_http_info(**kwargs)

    def list_user_organizations(
        self,
        user_id: str,
    ) -> UserResponse:
        """Get a user organization.

        Get a user organization. Returns the user information and all organizations
        joined by this user.

        :param user_id: The ID of the user.
        :type user_id: str
        :rtype: UserResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["user_id"] = user_id

        return self._list_user_organizations_endpoint.call_with_http_info(**kwargs)

    def list_user_permissions(
        self,
        user_id: str,
    ) -> PermissionsResponse:
        """Get a user permissions.

        Get a user permission set. Returns a list of the user’s permissions
        granted by the associated user's roles.

        :param user_id: The ID of the user.
        :type user_id: str
        :rtype: PermissionsResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["user_id"] = user_id

        return self._list_user_permissions_endpoint.call_with_http_info(**kwargs)

    def list_users(
        self,
        *,
        page_size: Union[int, UnsetType] = unset,
        page_number: Union[int, UnsetType] = unset,
        sort: Union[str, UnsetType] = unset,
        sort_dir: Union[QuerySortOrder, UnsetType] = unset,
        filter: Union[str, UnsetType] = unset,
        filter_status: Union[str, UnsetType] = unset,
    ) -> UsersResponse:
        """List all users.

        Get the list of all users in the organization. This list includes
        all users even if they are deactivated or unverified.

        :param page_size: Size for a given page. The maximum allowed value is 5000.
        :type page_size: int, optional
        :param page_number: Specific page number to return.
        :type page_number: int, optional
        :param sort: User attribute to order results by. Sort order is ascending by default.
            Sort order is descending if the field
            is prefixed by a negative sign, for example ``sort=-name``. Options: ``name`` ,
            ``modified_at`` , ``user_count``.
        :type sort: str, optional
        :param sort_dir: Direction of sort. Options: ``asc`` , ``desc``.
        :type sort_dir: QuerySortOrder, optional
        :param filter: Filter all users by the given string. Defaults to no filtering.
        :type filter: str, optional
        :param filter_status: Filter on status attribute.
            Comma separated list, with possible values ``Active`` , ``Pending`` , and ``Disabled``.
            Defaults to no filtering.
        :type filter_status: str, optional
        :rtype: UsersResponse
        """
        kwargs: Dict[str, Any] = {}
        if page_size is not unset:
            kwargs["page_size"] = page_size

        if page_number is not unset:
            kwargs["page_number"] = page_number

        if sort is not unset:
            kwargs["sort"] = sort

        if sort_dir is not unset:
            kwargs["sort_dir"] = sort_dir

        if filter is not unset:
            kwargs["filter"] = filter

        if filter_status is not unset:
            kwargs["filter_status"] = filter_status

        return self._list_users_endpoint.call_with_http_info(**kwargs)

    def send_invitations(
        self,
        body: UserInvitationsRequest,
    ) -> UserInvitationsResponse:
        """Send invitation emails.

        Sends emails to one or more users inviting them to join the organization.

        :type body: UserInvitationsRequest
        :rtype: UserInvitationsResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._send_invitations_endpoint.call_with_http_info(**kwargs)

    def update_user(
        self,
        user_id: str,
        body: UserUpdateRequest,
    ) -> UserResponse:
        """Update a user.

        Edit a user. Can only be used with an application key belonging
        to an administrator user.

        :param user_id: The ID of the user.
        :type user_id: str
        :type body: UserUpdateRequest
        :rtype: UserResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["user_id"] = user_id

        kwargs["body"] = body

        return self._update_user_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class SlackIntegrationChannelDisplay(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "message": (bool,),
            "notified": (bool,),
            "snapshot": (bool,),
            "tags": (bool,),
        }

    attribute_map = {
        "message": "message",
        "notified": "notified",
        "snapshot": "snapshot",
        "tags": "tags",
    }

    def __init__(
        self_,
        message: Union[bool, UnsetType] = unset,
        notified: Union[bool, UnsetType] = unset,
        snapshot: Union[bool, UnsetType] = unset,
        tags: Union[bool, UnsetType] = unset,
        **kwargs,
    ):
        """
        Configuration options for what is shown in an alert event message.

        :param message: Show the main body of the alert event.
        :type message: bool, optional

        :param notified: Show the list of @-handles in the alert event.
        :type notified: bool, optional

        :param snapshot: Show the alert event's snapshot image.
        :type snapshot: bool, optional

        :param tags: Show the scopes on which the monitor alerted.
        :type tags: bool, optional
        """
        if message is not unset:
            kwargs["message"] = message
        if notified is not unset:
            kwargs["notified"] = notified
        if snapshot is not unset:
            kwargs["snapshot"] = snapshot
        if tags is not unset:
            kwargs["tags"] = tags
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.event import Event
    from datadog_api_client.v2.model.monitor_type import MonitorType
    from datadog_api_client.v2.model.event_priority import EventPriority
    from datadog_api_client.v2.model.event_status_type import EventStatusType


class EventAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.event import Event
        from datadog_api_client.v2.model.monitor_type import MonitorType
        from datadog_api_client.v2.model.event_priority import EventPriority
        from datadog_api_client.v2.model.event_status_type import EventStatusType

        return {
            "aggregation_key": (str,),
            "date_happened": (int,),
            "device_name": (str,),
            "duration": (int,),
            "event_object": (str,),
            "evt": (Event,),
            "hostname": (str,),
            "monitor": (MonitorType,),
            "monitor_groups": ([str], none_type),
            "monitor_id": (int, none_type),
            "priority": (EventPriority,),
            "related_event_id": (int,),
            "service": (str,),
            "source_type_name": (str,),
            "sourcecategory": (str,),
            "status": (EventStatusType,),
            "tags": ([str],),
            "timestamp": (int,),
            "title": (str,),
        }

    attribute_map = {
        "aggregation_key": "aggregation_key",
        "date_happened": "date_happened",
        "device_name": "device_name",
        "duration": "duration",
        "event_object": "event_object",
        "evt": "evt",
        "hostname": "hostname",
        "monitor": "monitor",
        "monitor_groups": "monitor_groups",
        "monitor_id": "monitor_id",
        "priority": "priority",
        "related_event_id": "related_event_id",
        "service": "service",
        "source_type_name": "source_type_name",
        "sourcecategory": "sourcecategory",
        "status": "status",
        "tags": "tags",
        "timestamp": "timestamp",
        "title": "title",
    }

    def __init__(
        self_,
        aggregation_key: Union[str, UnsetType] = unset,
        date_happened: Union[int, UnsetType] = unset,
        device_name: Union[str, UnsetType] = unset,
        duration: Union[int, UnsetType] = unset,
        event_object: Union[str, UnsetType] = unset,
        evt: Union[Event, UnsetType] = unset,
        hostname: Union[str, UnsetType] = unset,
        monitor: Union[MonitorType, none_type, UnsetType] = unset,
        monitor_groups: Union[List[str], none_type, UnsetType] = unset,
        monitor_id: Union[int, none_type, UnsetType] = unset,
        priority: Union[EventPriority, none_type, UnsetType] = unset,
        related_event_id: Union[int, UnsetType] = unset,
        service: Union[str, UnsetType] = unset,
        source_type_name: Union[str, UnsetType] = unset,
        sourcecategory: Union[str, UnsetType] = unset,
        status: Union[EventStatusType, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        timestamp: Union[int, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object description of attributes from your event.

        :param aggregation_key: Aggregation key of the event.
        :type aggregation_key: str, optional

        :param date_happened: POSIX timestamp of the event. Must be sent as an integer (no quotation marks).
            Limited to events no older than 18 hours.
        :type date_happened: int, optional

        :param device_name: A device name.
        :type device_name: str, optional

        :param duration: The duration between the triggering of the event and its recovery in nanoseconds.
        :type duration: int, optional

        :param event_object: The event title.
        :type event_object: str, optional

        :param evt: The metadata associated with a request.
        :type evt: Event, optional

        :param hostname: Host name to associate with the event.
            Any tags associated with the host are also applied to this event.
        :type hostname: str, optional

        :param monitor: Attributes from the monitor that triggered the event.
        :type monitor: MonitorType, none_type, optional

        :param monitor_groups: List of groups referred to in the event.
        :type monitor_groups: [str], none_type, optional

        :param monitor_id: ID of the monitor that triggered the event. When an event isn't related to a monitor, this field is empty.
        :type monitor_id: int, none_type, optional

        :param priority: The priority of the event's monitor. For example, ``normal`` or ``low``.
        :type priority: EventPriority, none_type, optional

        :param related_event_id: Related event ID.
        :type related_event_id: int, optional

        :param service: Service that triggered the event.
        :type service: str, optional

        :param source_type_name: The type of event being posted.
            For example, ``nagios`` , ``hudson`` , ``jenkins`` , ``my_apps`` , ``chef`` , ``puppet`` , ``git`` or ``bitbucket``.
            The list of standard source attribute values is `available here <https://docs.datadoghq.com/integrations/faq/list-of-api-source-attribute-value>`_.
        :type source_type_name: str, optional

        :param sourcecategory: Identifier for the source of the event, such as a monitor alert, an externally-submitted event, or an integration.
        :type sourcecategory: str, optional

        :param status: If an alert event is enabled, its status is one of the following:
            ``failure`` , ``error`` , ``warning`` , ``info`` , ``success`` , ``user_update`` ,
            ``recommendation`` , or ``snapshot``.
        :type status: EventStatusType, optional

        :param tags: A list of tags to apply to the event.
        :type tags: [str], optional

        :param timestamp: POSIX timestamp of your event in milliseconds.
        :type timestamp: int, optional

        :param title: The event title.
        :type title: str, optional
        """
        if aggregation_key is not unset:
            kwargs["aggregation_key"] = aggregation_key
        if date_happened is not unset:
            kwargs["date_happened"] = date_happened
        if device_name is not unset:
            kwargs["device_name"] = device_name
        if duration is not unset:
            kwargs["duration"] = duration
        if event_object is not unset:
            kwargs["event_object"] = event_object
        if evt is not unset:
            kwargs["evt"] = evt
        if hostname is not unset:
            kwargs["hostname"] = hostname
        if monitor is not unset:
            kwargs["monitor"] = monitor
        if monitor_groups is not unset:
            kwargs["monitor_groups"] = monitor_groups
        if monitor_id is not unset:
            kwargs["monitor_id"] = monitor_id
        if priority is not unset:
            kwargs["priority"] = priority
        if related_event_id is not unset:
            kwargs["related_event_id"] = related_event_id
        if service is not unset:
            kwargs["service"] = service
        if source_type_name is not unset:
            kwargs["source_type_name"] = source_type_name
        if sourcecategory is not unset:
            kwargs["sourcecategory"] = sourcecategory
        if status is not unset:
            kwargs["status"] = status
        if tags is not unset:
            kwargs["tags"] = tags
        if timestamp is not unset:
            kwargs["timestamp"] = timestamp
        if title is not unset:
            kwargs["title"] = title
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.incident_attachment_update_data import IncidentAttachmentUpdateData


class IncidentAttachmentUpdateRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.incident_attachment_update_data import IncidentAttachmentUpdateData

        return {
            "data": ([IncidentAttachmentUpdateData],),
        }

    attribute_map = {
        "data": "data",
    }

    def __init__(self_, data: List[IncidentAttachmentUpdateData], **kwargs):
        """
        The update request for an incident's attachments.

        :param data: An array of incident attachments. An attachment object without an "id" key indicates that you want to
            create that attachment. An attachment object without an "attributes" key indicates that you want to
            delete that attachment. An attachment object with both the "id" key and a populated "attributes" object
            indicates that you want to update that attachment.
        :type data: [IncidentAttachmentUpdateData]
        """
        super().__init__(kwargs)

        self_.data = data



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelComposed,
    cached_property,
)


class MonitorFormulaAndFunctionQueryDefinition(ModelComposed):
    def __init__(self, **kwargs):
        """
        A formula and function query.

        :param compute: Compute options.
        :type compute: MonitorFormulaAndFunctionEventQueryDefinitionCompute

        :param data_source: Data source for event platform-based queries.
        :type data_source: MonitorFormulaAndFunctionEventsDataSource

        :param group_by: Group by options.
        :type group_by: [MonitorFormulaAndFunctionEventQueryGroupBy], optional

        :param indexes: An array of index names to query in the stream. Omit or use `[]` to query all indexes at once.
        :type indexes: [str], optional

        :param name: Name of the query for use in formulas.
        :type name: str

        :param search: Search options.
        :type search: MonitorFormulaAndFunctionEventQueryDefinitionSearch, optional
        """
        super().__init__(kwargs)

    @cached_property
    def _composed_schemas(_):
        # we need this here to make our import statements work
        # we must store _composed_schemas in here so the code is only run
        # when we invoke this method. If we kept this at the class
        # level we would get an error because the class level
        # code would be run when this module is imported, and these composed
        # classes don't exist yet because their module has not finished
        # loading
        from datadog_api_client.v1.model.monitor_formula_and_function_event_query_definition import (
            MonitorFormulaAndFunctionEventQueryDefinition,
        )

        return {
            "oneOf": [
                MonitorFormulaAndFunctionEventQueryDefinition,
            ],
        }



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class ConfluentAccountResourceAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "id": (str,),
            "resource_type": (str,),
            "tags": ([str],),
        }

    attribute_map = {
        "id": "id",
        "resource_type": "resource_type",
        "tags": "tags",
    }

    def __init__(
        self_,
        id: Union[str, UnsetType] = unset,
        resource_type: Union[str, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        **kwargs,
    ):
        """
        Attributes object for updating a Confluent resource.

        :param id: The ID associated with a Confluent resource.
        :type id: str, optional

        :param resource_type: The resource type of the Resource. Can be ``kafka`` , ``connector`` , ``ksql`` , or ``schema_registry``.
        :type resource_type: str, optional

        :param tags: A list of strings representing tags. Can be a single key, or key-value pairs separated by a colon.
        :type tags: [str], optional
        """
        if id is not unset:
            kwargs["id"] = id
        if resource_type is not unset:
            kwargs["resource_type"] = resource_type
        if tags is not unset:
            kwargs["tags"] = tags
        super().__init__(kwargs)



"""
Get a list of security signals returns "OK" response with pagination
"""

from datetime import datetime
from dateutil.relativedelta import relativedelta
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi
from datadog_api_client.v2.model.security_monitoring_signal_list_request import SecurityMonitoringSignalListRequest
from datadog_api_client.v2.model.security_monitoring_signal_list_request_filter import (
    SecurityMonitoringSignalListRequestFilter,
)
from datadog_api_client.v2.model.security_monitoring_signal_list_request_page import (
    SecurityMonitoringSignalListRequestPage,
)
from datadog_api_client.v2.model.security_monitoring_signals_sort import SecurityMonitoringSignalsSort

body = SecurityMonitoringSignalListRequest(
    filter=SecurityMonitoringSignalListRequestFilter(
        _from=(datetime.now() + relativedelta(minutes=-15)),
        query="security:attack status:high",
        to=datetime.now(),
    ),
    page=SecurityMonitoringSignalListRequestPage(
        limit=2,
    ),
    sort=SecurityMonitoringSignalsSort.TIMESTAMP_ASCENDING,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SecurityMonitoringApi(api_client)
    items = api_instance.search_security_monitoring_signals_with_pagination(body=body)
    for item in items:
        print(item)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class GCPAccount(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "auth_provider_x509_cert_url": (str,),
            "auth_uri": (str,),
            "automute": (bool,),
            "client_email": (str,),
            "client_id": (str,),
            "client_x509_cert_url": (str,),
            "errors": ([str],),
            "host_filters": (str,),
            "private_key": (str,),
            "private_key_id": (str,),
            "project_id": (str,),
            "token_uri": (str,),
            "type": (str,),
        }

    attribute_map = {
        "auth_provider_x509_cert_url": "auth_provider_x509_cert_url",
        "auth_uri": "auth_uri",
        "automute": "automute",
        "client_email": "client_email",
        "client_id": "client_id",
        "client_x509_cert_url": "client_x509_cert_url",
        "errors": "errors",
        "host_filters": "host_filters",
        "private_key": "private_key",
        "private_key_id": "private_key_id",
        "project_id": "project_id",
        "token_uri": "token_uri",
        "type": "type",
    }

    def __init__(
        self_,
        auth_provider_x509_cert_url: Union[str, UnsetType] = unset,
        auth_uri: Union[str, UnsetType] = unset,
        automute: Union[bool, UnsetType] = unset,
        client_email: Union[str, UnsetType] = unset,
        client_id: Union[str, UnsetType] = unset,
        client_x509_cert_url: Union[str, UnsetType] = unset,
        errors: Union[List[str], UnsetType] = unset,
        host_filters: Union[str, UnsetType] = unset,
        private_key: Union[str, UnsetType] = unset,
        private_key_id: Union[str, UnsetType] = unset,
        project_id: Union[str, UnsetType] = unset,
        token_uri: Union[str, UnsetType] = unset,
        type: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Your Google Cloud Platform Account.

        :param auth_provider_x509_cert_url: Should be ``https://www.googleapis.com/oauth2/v1/certs``.
        :type auth_provider_x509_cert_url: str, optional

        :param auth_uri: Should be ``https://accounts.google.com/o/oauth2/auth``.
        :type auth_uri: str, optional

        :param automute: Silence monitors for expected GCE instance shutdowns.
        :type automute: bool, optional

        :param client_email: Your email found in your JSON service account key.
        :type client_email: str, optional

        :param client_id: Your ID found in your JSON service account key.
        :type client_id: str, optional

        :param client_x509_cert_url: Should be ``https://www.googleapis.com/robot/v1/metadata/x509/$CLIENT_EMAIL``
            where ``$CLIENT_EMAIL`` is the email found in your JSON service account key.
        :type client_x509_cert_url: str, optional

        :param errors: An array of errors.
        :type errors: [str], optional

        :param host_filters: Limit the GCE instances that are pulled into Datadog by using tags.
            Only hosts that match one of the defined tags are imported into Datadog.
        :type host_filters: str, optional

        :param private_key: Your private key name found in your JSON service account key.
        :type private_key: str, optional

        :param private_key_id: Your private key ID found in your JSON service account key.
        :type private_key_id: str, optional

        :param project_id: Your Google Cloud project ID found in your JSON service account key.
        :type project_id: str, optional

        :param token_uri: Should be ``https://accounts.google.com/o/oauth2/token``.
        :type token_uri: str, optional

        :param type: The value for service_account found in your JSON service account key.
        :type type: str, optional
        """
        if auth_provider_x509_cert_url is not unset:
            kwargs["auth_provider_x509_cert_url"] = auth_provider_x509_cert_url
        if auth_uri is not unset:
            kwargs["auth_uri"] = auth_uri
        if automute is not unset:
            kwargs["automute"] = automute
        if client_email is not unset:
            kwargs["client_email"] = client_email
        if client_id is not unset:
            kwargs["client_id"] = client_id
        if client_x509_cert_url is not unset:
            kwargs["client_x509_cert_url"] = client_x509_cert_url
        if errors is not unset:
            kwargs["errors"] = errors
        if host_filters is not unset:
            kwargs["host_filters"] = host_filters
        if private_key is not unset:
            kwargs["private_key"] = private_key
        if private_key_id is not unset:
            kwargs["private_key_id"] = private_key_id
        if project_id is not unset:
            kwargs["project_id"] = project_id
        if token_uri is not unset:
            kwargs["token_uri"] = token_uri
        if type is not unset:
            kwargs["type"] = type
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_restricted_roles import SyntheticsRestrictedRoles


class SyntheticsGlobalVariableAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_restricted_roles import SyntheticsRestrictedRoles

        return {
            "restricted_roles": (SyntheticsRestrictedRoles,),
        }

    attribute_map = {
        "restricted_roles": "restricted_roles",
    }

    def __init__(self_, restricted_roles: Union[SyntheticsRestrictedRoles, UnsetType] = unset, **kwargs):
        """
        Attributes of the global variable.

        :param restricted_roles: A list of role identifiers that can be pulled from the Roles API, for restricting read and write access.
        :type restricted_roles: SyntheticsRestrictedRoles, optional
        """
        if restricted_roles is not unset:
            kwargs["restricted_roles"] = restricted_roles
        super().__init__(kwargs)
